# API Reference <a name="API Reference" id="api-reference"></a>


## Structs <a name="Structs" id="Structs"></a>

### AccountInfo <a name="AccountInfo" id="@wasend/core.AccountInfo"></a>

Account information structure.

#### Initializer <a name="Initializer" id="@wasend/core.AccountInfo.Initializer"></a>

```typescript
import { AccountInfo } from '@wasend/core'

const accountInfo: AccountInfo = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.AccountInfo.property.id">id</a></code> | <code>string</code> | Account ID. |
| <code><a href="#@wasend/core.AccountInfo.property.name">name</a></code> | <code>string</code> | Account name. |
| <code><a href="#@wasend/core.AccountInfo.property.plan">plan</a></code> | <code>string</code> | Account plan. |

---

##### `id`<sup>Required</sup> <a name="id" id="@wasend/core.AccountInfo.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Account ID.

---

##### `name`<sup>Required</sup> <a name="name" id="@wasend/core.AccountInfo.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Account name.

---

##### `plan`<sup>Required</sup> <a name="plan" id="@wasend/core.AccountInfo.property.plan"></a>

```typescript
public readonly plan: string;
```

- *Type:* string

Account plan.

---

### ApiResponse <a name="ApiResponse" id="@wasend/core.ApiResponse"></a>

Response from API calls.

#### Initializer <a name="Initializer" id="@wasend/core.ApiResponse.Initializer"></a>

```typescript
import { ApiResponse } from '@wasend/core'

const apiResponse: ApiResponse = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.ApiResponse.property.success">success</a></code> | <code>boolean</code> | Whether the request was successful. |
| <code><a href="#@wasend/core.ApiResponse.property.data">data</a></code> | <code>any</code> | The response data (if successful). |
| <code><a href="#@wasend/core.ApiResponse.property.error">error</a></code> | <code>string</code> | Error message if the request failed. |

---

##### `success`<sup>Required</sup> <a name="success" id="@wasend/core.ApiResponse.property.success"></a>

```typescript
public readonly success: boolean;
```

- *Type:* boolean

Whether the request was successful.

---

##### `data`<sup>Optional</sup> <a name="data" id="@wasend/core.ApiResponse.property.data"></a>

```typescript
public readonly data: any;
```

- *Type:* any

The response data (if successful).

---

##### `error`<sup>Optional</sup> <a name="error" id="@wasend/core.ApiResponse.property.error"></a>

```typescript
public readonly error: string;
```

- *Type:* string

Error message if the request failed.

---

### ChatRequest <a name="ChatRequest" id="@wasend/core.ChatRequest"></a>

Base chat request interface.

#### Initializer <a name="Initializer" id="@wasend/core.ChatRequest.Initializer"></a>

```typescript
import { ChatRequest } from '@wasend/core'

const chatRequest: ChatRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.ChatRequest.property.session">session</a></code> | <code>string</code> | The session ID. |
| <code><a href="#@wasend/core.ChatRequest.property.to">to</a></code> | <code>string</code> | The recipient's phone number or group JID. |

---

##### `session`<sup>Required</sup> <a name="session" id="@wasend/core.ChatRequest.property.session"></a>

```typescript
public readonly session: string;
```

- *Type:* string

The session ID.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.ChatRequest.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient's phone number or group JID.

---

*Example*

```typescript
"+1234567890" or "1234567890-12345678@g.us"
```


### CheckContactExistsQueryParams <a name="CheckContactExistsQueryParams" id="@wasend/core.CheckContactExistsQueryParams"></a>

Check contact exists query parameters.

#### Initializer <a name="Initializer" id="@wasend/core.CheckContactExistsQueryParams.Initializer"></a>

```typescript
import { CheckContactExistsQueryParams } from '@wasend/core'

const checkContactExistsQueryParams: CheckContactExistsQueryParams = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.CheckContactExistsQueryParams.property.phone">phone</a></code> | <code>string</code> | The phone number to check. |

---

##### `phone`<sup>Required</sup> <a name="phone" id="@wasend/core.CheckContactExistsQueryParams.property.phone"></a>

```typescript
public readonly phone: string;
```

- *Type:* string

The phone number to check.

---

*Example*

```typescript
"1213213213"
```


### Contact <a name="Contact" id="@wasend/core.Contact"></a>

Contact information.

#### Initializer <a name="Initializer" id="@wasend/core.Contact.Initializer"></a>

```typescript
import { Contact } from '@wasend/core'

const contact: Contact = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.Contact.property.id">id</a></code> | <code>string</code> | Contact ID (phone number with. |
| <code><a href="#@wasend/core.Contact.property.phoneNumber">phoneNumber</a></code> | <code>string</code> | Contact phone number. |
| <code><a href="#@wasend/core.Contact.property.businessProfile">businessProfile</a></code> | <code>{[ key: string ]: string}</code> | Contact business profile. |
| <code><a href="#@wasend/core.Contact.property.name">name</a></code> | <code>string</code> | Contact name. |
| <code><a href="#@wasend/core.Contact.property.profilePictureUrl">profilePictureUrl</a></code> | <code>string</code> | Contact profile picture URL. |
| <code><a href="#@wasend/core.Contact.property.pushName">pushName</a></code> | <code>string</code> | Contact push name. |
| <code><a href="#@wasend/core.Contact.property.status">status</a></code> | <code>string</code> | Contact status. |

---

##### `id`<sup>Required</sup> <a name="id" id="@wasend/core.Contact.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Contact ID (phone number with.

---

*Example*

```typescript
"11111111111@c.us"
```


##### `phoneNumber`<sup>Required</sup> <a name="phoneNumber" id="@wasend/core.Contact.property.phoneNumber"></a>

```typescript
public readonly phoneNumber: string;
```

- *Type:* string

Contact phone number.

---

##### `businessProfile`<sup>Optional</sup> <a name="businessProfile" id="@wasend/core.Contact.property.businessProfile"></a>

```typescript
public readonly businessProfile: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Contact business profile.

---

##### `name`<sup>Optional</sup> <a name="name" id="@wasend/core.Contact.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Contact name.

---

##### `profilePictureUrl`<sup>Optional</sup> <a name="profilePictureUrl" id="@wasend/core.Contact.property.profilePictureUrl"></a>

```typescript
public readonly profilePictureUrl: string;
```

- *Type:* string

Contact profile picture URL.

---

##### `pushName`<sup>Optional</sup> <a name="pushName" id="@wasend/core.Contact.property.pushName"></a>

```typescript
public readonly pushName: string;
```

- *Type:* string

Contact push name.

---

##### `status`<sup>Optional</sup> <a name="status" id="@wasend/core.Contact.property.status"></a>

```typescript
public readonly status: string;
```

- *Type:* string

Contact status.

---

### CountResponse <a name="CountResponse" id="@wasend/core.CountResponse"></a>

Response for count operations.

#### Initializer <a name="Initializer" id="@wasend/core.CountResponse.Initializer"></a>

```typescript
import { CountResponse } from '@wasend/core'

const countResponse: CountResponse = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.CountResponse.property.total">total</a></code> | <code>number</code> | The total count. |
| <code><a href="#@wasend/core.CountResponse.property.byStatus">byStatus</a></code> | <code>{[ key: string ]: string}</code> | Count breakdown by status. |

---

##### `total`<sup>Required</sup> <a name="total" id="@wasend/core.CountResponse.property.total"></a>

```typescript
public readonly total: number;
```

- *Type:* number

The total count.

---

##### `byStatus`<sup>Optional</sup> <a name="byStatus" id="@wasend/core.CountResponse.property.byStatus"></a>

```typescript
public readonly byStatus: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Count breakdown by status.

---

*Example*

```typescript
{
  "ACTIVE": "10",
  "ARCHIVED": "5",
  "DELETED": "2"
}
```


### CreateGroupParticipant <a name="CreateGroupParticipant" id="@wasend/core.CreateGroupParticipant"></a>

Create group request participant.

#### Initializer <a name="Initializer" id="@wasend/core.CreateGroupParticipant.Initializer"></a>

```typescript
import { CreateGroupParticipant } from '@wasend/core'

const createGroupParticipant: CreateGroupParticipant = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.CreateGroupParticipant.property.id">id</a></code> | <code>string</code> | Participant ID (phone number with country code). |
| <code><a href="#@wasend/core.CreateGroupParticipant.property.isAdmin">isAdmin</a></code> | <code>boolean</code> | Whether to make the participant an admin. |

---

##### `id`<sup>Required</sup> <a name="id" id="@wasend/core.CreateGroupParticipant.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Participant ID (phone number with country code).

---

*Example*

```typescript
"+919545251359"
```


##### `isAdmin`<sup>Optional</sup> <a name="isAdmin" id="@wasend/core.CreateGroupParticipant.property.isAdmin"></a>

```typescript
public readonly isAdmin: boolean;
```

- *Type:* boolean
- *Default:* false

Whether to make the participant an admin.

---

### CreateGroupRequest <a name="CreateGroupRequest" id="@wasend/core.CreateGroupRequest"></a>

Create group request.

#### Initializer <a name="Initializer" id="@wasend/core.CreateGroupRequest.Initializer"></a>

```typescript
import { CreateGroupRequest } from '@wasend/core'

const createGroupRequest: CreateGroupRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.CreateGroupRequest.property.name">name</a></code> | <code>string</code> | Group name. |
| <code><a href="#@wasend/core.CreateGroupRequest.property.participants">participants</a></code> | <code><a href="#@wasend/core.CreateGroupParticipant">CreateGroupParticipant</a>[]</code> | Group participants. |
| <code><a href="#@wasend/core.CreateGroupRequest.property.description">description</a></code> | <code>string</code> | Group description (optional). |
| <code><a href="#@wasend/core.CreateGroupRequest.property.pictureUrl">pictureUrl</a></code> | <code>string</code> | Group picture URL (optional). |
| <code><a href="#@wasend/core.CreateGroupRequest.property.tags">tags</a></code> | <code>string[]</code> | Group tags (optional). |

---

##### `name`<sup>Required</sup> <a name="name" id="@wasend/core.CreateGroupRequest.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Group name.

---

##### `participants`<sup>Required</sup> <a name="participants" id="@wasend/core.CreateGroupRequest.property.participants"></a>

```typescript
public readonly participants: CreateGroupParticipant[];
```

- *Type:* <a href="#@wasend/core.CreateGroupParticipant">CreateGroupParticipant</a>[]

Group participants.

---

##### `description`<sup>Optional</sup> <a name="description" id="@wasend/core.CreateGroupRequest.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

Group description (optional).

---

##### `pictureUrl`<sup>Optional</sup> <a name="pictureUrl" id="@wasend/core.CreateGroupRequest.property.pictureUrl"></a>

```typescript
public readonly pictureUrl: string;
```

- *Type:* string

Group picture URL (optional).

---

##### `tags`<sup>Optional</sup> <a name="tags" id="@wasend/core.CreateGroupRequest.property.tags"></a>

```typescript
public readonly tags: string[];
```

- *Type:* string[]

Group tags (optional).

---

### DescriptionRequest <a name="DescriptionRequest" id="@wasend/core.DescriptionRequest"></a>

Description request.

#### Initializer <a name="Initializer" id="@wasend/core.DescriptionRequest.Initializer"></a>

```typescript
import { DescriptionRequest } from '@wasend/core'

const descriptionRequest: DescriptionRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.DescriptionRequest.property.description">description</a></code> | <code>string</code> | Group description. |

---

##### `description`<sup>Required</sup> <a name="description" id="@wasend/core.DescriptionRequest.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

Group description.

---

### DownstreamInfo <a name="DownstreamInfo" id="@wasend/core.DownstreamInfo"></a>

Downstream connection information.

#### Initializer <a name="Initializer" id="@wasend/core.DownstreamInfo.Initializer"></a>

```typescript
import { DownstreamInfo } from '@wasend/core'

const downstreamInfo: DownstreamInfo = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.DownstreamInfo.property.config">config</a></code> | <code><a href="#@wasend/core.SessionConfig">SessionConfig</a></code> | Configuration for the downstream connection. |
| <code><a href="#@wasend/core.DownstreamInfo.property.engine">engine</a></code> | <code><a href="#@wasend/core.EngineStatus">EngineStatus</a></code> | Engine status information. |
| <code><a href="#@wasend/core.DownstreamInfo.property.name">name</a></code> | <code>string</code> | Name of the downstream connection. |
| <code><a href="#@wasend/core.DownstreamInfo.property.status">status</a></code> | <code>string</code> | Status of the downstream connection. |

---

##### `config`<sup>Required</sup> <a name="config" id="@wasend/core.DownstreamInfo.property.config"></a>

```typescript
public readonly config: SessionConfig;
```

- *Type:* <a href="#@wasend/core.SessionConfig">SessionConfig</a>

Configuration for the downstream connection.

---

##### `engine`<sup>Required</sup> <a name="engine" id="@wasend/core.DownstreamInfo.property.engine"></a>

```typescript
public readonly engine: EngineStatus;
```

- *Type:* <a href="#@wasend/core.EngineStatus">EngineStatus</a>

Engine status information.

---

##### `name`<sup>Required</sup> <a name="name" id="@wasend/core.DownstreamInfo.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the downstream connection.

---

##### `status`<sup>Required</sup> <a name="status" id="@wasend/core.DownstreamInfo.property.status"></a>

```typescript
public readonly status: string;
```

- *Type:* string

Status of the downstream connection.

---

### EngineStatus <a name="EngineStatus" id="@wasend/core.EngineStatus"></a>

Engine status information.

#### Initializer <a name="Initializer" id="@wasend/core.EngineStatus.Initializer"></a>

```typescript
import { EngineStatus } from '@wasend/core'

const engineStatus: EngineStatus = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.EngineStatus.property.gows">gows</a></code> | <code><a href="#@wasend/core.GowsStatus">GowsStatus</a></code> | GoWS status. |
| <code><a href="#@wasend/core.EngineStatus.property.grpc">grpc</a></code> | <code><a href="#@wasend/core.GrpcStatus">GrpcStatus</a></code> | gRPC status. |

---

##### `gows`<sup>Required</sup> <a name="gows" id="@wasend/core.EngineStatus.property.gows"></a>

```typescript
public readonly gows: GowsStatus;
```

- *Type:* <a href="#@wasend/core.GowsStatus">GowsStatus</a>

GoWS status.

---

##### `grpc`<sup>Required</sup> <a name="grpc" id="@wasend/core.EngineStatus.property.grpc"></a>

```typescript
public readonly grpc: GrpcStatus;
```

- *Type:* <a href="#@wasend/core.GrpcStatus">GrpcStatus</a>

gRPC status.

---

### GetAllSessionsResponse <a name="GetAllSessionsResponse" id="@wasend/core.GetAllSessionsResponse"></a>

Response wrapper for getAllSessions.

#### Initializer <a name="Initializer" id="@wasend/core.GetAllSessionsResponse.Initializer"></a>

```typescript
import { GetAllSessionsResponse } from '@wasend/core'

const getAllSessionsResponse: GetAllSessionsResponse = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.GetAllSessionsResponse.property.sessions">sessions</a></code> | <code><a href="#@wasend/core.SessionListItem">SessionListItem</a>[]</code> | Array of sessions. |

---

##### `sessions`<sup>Required</sup> <a name="sessions" id="@wasend/core.GetAllSessionsResponse.property.sessions"></a>

```typescript
public readonly sessions: SessionListItem[];
```

- *Type:* <a href="#@wasend/core.SessionListItem">SessionListItem</a>[]

Array of sessions.

---

### GetContactQueryParams <a name="GetContactQueryParams" id="@wasend/core.GetContactQueryParams"></a>

Get contact query parameters.

#### Initializer <a name="Initializer" id="@wasend/core.GetContactQueryParams.Initializer"></a>

```typescript
import { GetContactQueryParams } from '@wasend/core'

const getContactQueryParams: GetContactQueryParams = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.GetContactQueryParams.property.contactId">contactId</a></code> | <code>string</code> | Contact ID (phone number with. |

---

##### `contactId`<sup>Required</sup> <a name="contactId" id="@wasend/core.GetContactQueryParams.property.contactId"></a>

```typescript
public readonly contactId: string;
```

- *Type:* string

Contact ID (phone number with.

---

*Example*

```typescript
"11111111111@c.us"
```


### GetContactsQueryParams <a name="GetContactsQueryParams" id="@wasend/core.GetContactsQueryParams"></a>

Get contacts query parameters.

#### Initializer <a name="Initializer" id="@wasend/core.GetContactsQueryParams.Initializer"></a>

```typescript
import { GetContactsQueryParams } from '@wasend/core'

const getContactsQueryParams: GetContactsQueryParams = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.GetContactsQueryParams.property.limit">limit</a></code> | <code>number</code> | Maximum number of results. |
| <code><a href="#@wasend/core.GetContactsQueryParams.property.offset">offset</a></code> | <code>number</code> | Number of results to skip. |
| <code><a href="#@wasend/core.GetContactsQueryParams.property.sortBy">sortBy</a></code> | <code>string</code> | Sort by field. |
| <code><a href="#@wasend/core.GetContactsQueryParams.property.sortOrder">sortOrder</a></code> | <code>string</code> | Sort order. |

---

##### `limit`<sup>Optional</sup> <a name="limit" id="@wasend/core.GetContactsQueryParams.property.limit"></a>

```typescript
public readonly limit: number;
```

- *Type:* number
- *Default:* 10

Maximum number of results.

---

##### `offset`<sup>Optional</sup> <a name="offset" id="@wasend/core.GetContactsQueryParams.property.offset"></a>

```typescript
public readonly offset: number;
```

- *Type:* number
- *Default:* 0

Number of results to skip.

---

##### `sortBy`<sup>Optional</sup> <a name="sortBy" id="@wasend/core.GetContactsQueryParams.property.sortBy"></a>

```typescript
public readonly sortBy: string;
```

- *Type:* string

Sort by field.

---

##### `sortOrder`<sup>Optional</sup> <a name="sortOrder" id="@wasend/core.GetContactsQueryParams.property.sortOrder"></a>

```typescript
public readonly sortOrder: string;
```

- *Type:* string

Sort order.

---

### GetGroupsQueryParams <a name="GetGroupsQueryParams" id="@wasend/core.GetGroupsQueryParams"></a>

Get groups query parameters.

#### Initializer <a name="Initializer" id="@wasend/core.GetGroupsQueryParams.Initializer"></a>

```typescript
import { GetGroupsQueryParams } from '@wasend/core'

const getGroupsQueryParams: GetGroupsQueryParams = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.GetGroupsQueryParams.property.exclude">exclude</a></code> | <code>string[]</code> | Fields to exclude from response. |
| <code><a href="#@wasend/core.GetGroupsQueryParams.property.limit">limit</a></code> | <code>number</code> | Maximum number of results. |
| <code><a href="#@wasend/core.GetGroupsQueryParams.property.offset">offset</a></code> | <code>number</code> | Number of results to skip. |
| <code><a href="#@wasend/core.GetGroupsQueryParams.property.search">search</a></code> | <code>string</code> | Search by name or description. |
| <code><a href="#@wasend/core.GetGroupsQueryParams.property.sortBy">sortBy</a></code> | <code>string</code> | Sort by field. |
| <code><a href="#@wasend/core.GetGroupsQueryParams.property.sortOrder">sortOrder</a></code> | <code>string</code> | Sort order. |
| <code><a href="#@wasend/core.GetGroupsQueryParams.property.status">status</a></code> | <code><a href="#@wasend/core.GroupStatus">GroupStatus</a></code> | Filter by status. |
| <code><a href="#@wasend/core.GetGroupsQueryParams.property.tags">tags</a></code> | <code>string[]</code> | Filter by tags. |

---

##### `exclude`<sup>Optional</sup> <a name="exclude" id="@wasend/core.GetGroupsQueryParams.property.exclude"></a>

```typescript
public readonly exclude: string[];
```

- *Type:* string[]

Fields to exclude from response.

---

##### `limit`<sup>Optional</sup> <a name="limit" id="@wasend/core.GetGroupsQueryParams.property.limit"></a>

```typescript
public readonly limit: number;
```

- *Type:* number
- *Default:* 50

Maximum number of results.

---

##### `offset`<sup>Optional</sup> <a name="offset" id="@wasend/core.GetGroupsQueryParams.property.offset"></a>

```typescript
public readonly offset: number;
```

- *Type:* number
- *Default:* 0

Number of results to skip.

---

##### `search`<sup>Optional</sup> <a name="search" id="@wasend/core.GetGroupsQueryParams.property.search"></a>

```typescript
public readonly search: string;
```

- *Type:* string

Search by name or description.

---

##### `sortBy`<sup>Optional</sup> <a name="sortBy" id="@wasend/core.GetGroupsQueryParams.property.sortBy"></a>

```typescript
public readonly sortBy: string;
```

- *Type:* string

Sort by field.

---

##### `sortOrder`<sup>Optional</sup> <a name="sortOrder" id="@wasend/core.GetGroupsQueryParams.property.sortOrder"></a>

```typescript
public readonly sortOrder: string;
```

- *Type:* string

Sort order.

---

##### `status`<sup>Optional</sup> <a name="status" id="@wasend/core.GetGroupsQueryParams.property.status"></a>

```typescript
public readonly status: GroupStatus;
```

- *Type:* <a href="#@wasend/core.GroupStatus">GroupStatus</a>

Filter by status.

---

##### `tags`<sup>Optional</sup> <a name="tags" id="@wasend/core.GetGroupsQueryParams.property.tags"></a>

```typescript
public readonly tags: string[];
```

- *Type:* string[]

Filter by tags.

---

### GetProfilePictureQueryParams <a name="GetProfilePictureQueryParams" id="@wasend/core.GetProfilePictureQueryParams"></a>

Get profile picture query parameters.

#### Initializer <a name="Initializer" id="@wasend/core.GetProfilePictureQueryParams.Initializer"></a>

```typescript
import { GetProfilePictureQueryParams } from '@wasend/core'

const getProfilePictureQueryParams: GetProfilePictureQueryParams = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.GetProfilePictureQueryParams.property.contactId">contactId</a></code> | <code>string</code> | Contact ID (phone number with. |
| <code><a href="#@wasend/core.GetProfilePictureQueryParams.property.refresh">refresh</a></code> | <code>boolean</code> | Refresh the picture from the server (24h cache by default). |

---

##### `contactId`<sup>Required</sup> <a name="contactId" id="@wasend/core.GetProfilePictureQueryParams.property.contactId"></a>

```typescript
public readonly contactId: string;
```

- *Type:* string

Contact ID (phone number with.

---

*Example*

```typescript
"11111111111@c.us"
```


##### `refresh`<sup>Optional</sup> <a name="refresh" id="@wasend/core.GetProfilePictureQueryParams.property.refresh"></a>

```typescript
public readonly refresh: boolean;
```

- *Type:* boolean
- *Default:* false

Refresh the picture from the server (24h cache by default).

---

### GowsStatus <a name="GowsStatus" id="@wasend/core.GowsStatus"></a>

#### Initializer <a name="Initializer" id="@wasend/core.GowsStatus.Initializer"></a>

```typescript
import { GowsStatus } from '@wasend/core'

const gowsStatus: GowsStatus = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.GowsStatus.property.connected">connected</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.GowsStatus.property.found">found</a></code> | <code>boolean</code> | *No description.* |

---

##### `connected`<sup>Required</sup> <a name="connected" id="@wasend/core.GowsStatus.property.connected"></a>

```typescript
public readonly connected: boolean;
```

- *Type:* boolean

---

##### `found`<sup>Required</sup> <a name="found" id="@wasend/core.GowsStatus.property.found"></a>

```typescript
public readonly found: boolean;
```

- *Type:* boolean

---

### Group <a name="Group" id="@wasend/core.Group"></a>

Group information.

#### Initializer <a name="Initializer" id="@wasend/core.Group.Initializer"></a>

```typescript
import { Group } from '@wasend/core'

const group: Group = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.Group.property.addressingMode">addressingMode</a></code> | <code>string</code> | Addressing mode. |
| <code><a href="#@wasend/core.Group.property.announceVersionId">announceVersionId</a></code> | <code>string</code> | Announcement version ID. |
| <code><a href="#@wasend/core.Group.property.creatorCountryCode">creatorCountryCode</a></code> | <code>string</code> | Creator's country code. |
| <code><a href="#@wasend/core.Group.property.defaultMembershipApprovalMode">defaultMembershipApprovalMode</a></code> | <code>string</code> | Default membership approval mode. |
| <code><a href="#@wasend/core.Group.property.disappearingTimer">disappearingTimer</a></code> | <code>number</code> | Disappearing messages timer in seconds. |
| <code><a href="#@wasend/core.Group.property.groupCreated">groupCreated</a></code> | <code>string</code> | When the group was created. |
| <code><a href="#@wasend/core.Group.property.isAnnounce">isAnnounce</a></code> | <code>boolean</code> | Whether the group is an announcement group. |
| <code><a href="#@wasend/core.Group.property.isDefaultSubGroup">isDefaultSubGroup</a></code> | <code>boolean</code> | Whether the group is a default subgroup. |
| <code><a href="#@wasend/core.Group.property.isEphemeral">isEphemeral</a></code> | <code>boolean</code> | Whether the group is ephemeral. |
| <code><a href="#@wasend/core.Group.property.isIncognito">isIncognito</a></code> | <code>boolean</code> | Whether the group is incognito. |
| <code><a href="#@wasend/core.Group.property.isJoinApprovalRequired">isJoinApprovalRequired</a></code> | <code>boolean</code> | Whether join approval is required. |
| <code><a href="#@wasend/core.Group.property.isLocked">isLocked</a></code> | <code>boolean</code> | Whether the group is locked. |
| <code><a href="#@wasend/core.Group.property.isParent">isParent</a></code> | <code>boolean</code> | Whether the group is a parent group. |
| <code><a href="#@wasend/core.Group.property.jid">jid</a></code> | <code>string</code> | Group JID. |
| <code><a href="#@wasend/core.Group.property.linkedParentJid">linkedParentJid</a></code> | <code>string</code> | Linked parent group JID. |
| <code><a href="#@wasend/core.Group.property.memberAddMode">memberAddMode</a></code> | <code>string</code> | Member add mode. |
| <code><a href="#@wasend/core.Group.property.name">name</a></code> | <code>string</code> | Group name. |
| <code><a href="#@wasend/core.Group.property.nameSetAt">nameSetAt</a></code> | <code>string</code> | When the name was set. |
| <code><a href="#@wasend/core.Group.property.nameSetBy">nameSetBy</a></code> | <code>string</code> | Who set the name. |
| <code><a href="#@wasend/core.Group.property.nameSetByPn">nameSetByPn</a></code> | <code>string</code> | Phone number of who set the name. |
| <code><a href="#@wasend/core.Group.property.ownerJid">ownerJid</a></code> | <code>string</code> | Owner JID. |
| <code><a href="#@wasend/core.Group.property.ownerPn">ownerPn</a></code> | <code>string</code> | Owner phone number. |
| <code><a href="#@wasend/core.Group.property.participants">participants</a></code> | <code><a href="#@wasend/core.GroupParticipant">GroupParticipant</a>[]</code> | Group participants. |
| <code><a href="#@wasend/core.Group.property.participantVersionId">participantVersionId</a></code> | <code>string</code> | Participant version ID. |
| <code><a href="#@wasend/core.Group.property.topic">topic</a></code> | <code>string</code> | Group topic/description. |
| <code><a href="#@wasend/core.Group.property.topicDeleted">topicDeleted</a></code> | <code>boolean</code> | Whether the topic was deleted. |
| <code><a href="#@wasend/core.Group.property.topicId">topicId</a></code> | <code>string</code> | Topic ID. |
| <code><a href="#@wasend/core.Group.property.topicSetAt">topicSetAt</a></code> | <code>string</code> | When the topic was set. |
| <code><a href="#@wasend/core.Group.property.topicSetBy">topicSetBy</a></code> | <code>string</code> | Who set the topic. |
| <code><a href="#@wasend/core.Group.property.topicSetByPn">topicSetByPn</a></code> | <code>string</code> | Phone number of who set the topic. |

---

##### `addressingMode`<sup>Required</sup> <a name="addressingMode" id="@wasend/core.Group.property.addressingMode"></a>

```typescript
public readonly addressingMode: string;
```

- *Type:* string

Addressing mode.

---

##### `announceVersionId`<sup>Required</sup> <a name="announceVersionId" id="@wasend/core.Group.property.announceVersionId"></a>

```typescript
public readonly announceVersionId: string;
```

- *Type:* string

Announcement version ID.

---

##### `creatorCountryCode`<sup>Required</sup> <a name="creatorCountryCode" id="@wasend/core.Group.property.creatorCountryCode"></a>

```typescript
public readonly creatorCountryCode: string;
```

- *Type:* string

Creator's country code.

---

##### `defaultMembershipApprovalMode`<sup>Required</sup> <a name="defaultMembershipApprovalMode" id="@wasend/core.Group.property.defaultMembershipApprovalMode"></a>

```typescript
public readonly defaultMembershipApprovalMode: string;
```

- *Type:* string

Default membership approval mode.

---

##### `disappearingTimer`<sup>Required</sup> <a name="disappearingTimer" id="@wasend/core.Group.property.disappearingTimer"></a>

```typescript
public readonly disappearingTimer: number;
```

- *Type:* number

Disappearing messages timer in seconds.

---

##### `groupCreated`<sup>Required</sup> <a name="groupCreated" id="@wasend/core.Group.property.groupCreated"></a>

```typescript
public readonly groupCreated: string;
```

- *Type:* string

When the group was created.

---

##### `isAnnounce`<sup>Required</sup> <a name="isAnnounce" id="@wasend/core.Group.property.isAnnounce"></a>

```typescript
public readonly isAnnounce: boolean;
```

- *Type:* boolean

Whether the group is an announcement group.

---

##### `isDefaultSubGroup`<sup>Required</sup> <a name="isDefaultSubGroup" id="@wasend/core.Group.property.isDefaultSubGroup"></a>

```typescript
public readonly isDefaultSubGroup: boolean;
```

- *Type:* boolean

Whether the group is a default subgroup.

---

##### `isEphemeral`<sup>Required</sup> <a name="isEphemeral" id="@wasend/core.Group.property.isEphemeral"></a>

```typescript
public readonly isEphemeral: boolean;
```

- *Type:* boolean

Whether the group is ephemeral.

---

##### `isIncognito`<sup>Required</sup> <a name="isIncognito" id="@wasend/core.Group.property.isIncognito"></a>

```typescript
public readonly isIncognito: boolean;
```

- *Type:* boolean

Whether the group is incognito.

---

##### `isJoinApprovalRequired`<sup>Required</sup> <a name="isJoinApprovalRequired" id="@wasend/core.Group.property.isJoinApprovalRequired"></a>

```typescript
public readonly isJoinApprovalRequired: boolean;
```

- *Type:* boolean

Whether join approval is required.

---

##### `isLocked`<sup>Required</sup> <a name="isLocked" id="@wasend/core.Group.property.isLocked"></a>

```typescript
public readonly isLocked: boolean;
```

- *Type:* boolean

Whether the group is locked.

---

##### `isParent`<sup>Required</sup> <a name="isParent" id="@wasend/core.Group.property.isParent"></a>

```typescript
public readonly isParent: boolean;
```

- *Type:* boolean

Whether the group is a parent group.

---

##### `jid`<sup>Required</sup> <a name="jid" id="@wasend/core.Group.property.jid"></a>

```typescript
public readonly jid: string;
```

- *Type:* string

Group JID.

---

##### `linkedParentJid`<sup>Required</sup> <a name="linkedParentJid" id="@wasend/core.Group.property.linkedParentJid"></a>

```typescript
public readonly linkedParentJid: string;
```

- *Type:* string

Linked parent group JID.

---

##### `memberAddMode`<sup>Required</sup> <a name="memberAddMode" id="@wasend/core.Group.property.memberAddMode"></a>

```typescript
public readonly memberAddMode: string;
```

- *Type:* string

Member add mode.

---

##### `name`<sup>Required</sup> <a name="name" id="@wasend/core.Group.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Group name.

---

##### `nameSetAt`<sup>Required</sup> <a name="nameSetAt" id="@wasend/core.Group.property.nameSetAt"></a>

```typescript
public readonly nameSetAt: string;
```

- *Type:* string

When the name was set.

---

##### `nameSetBy`<sup>Required</sup> <a name="nameSetBy" id="@wasend/core.Group.property.nameSetBy"></a>

```typescript
public readonly nameSetBy: string;
```

- *Type:* string

Who set the name.

---

##### `nameSetByPn`<sup>Required</sup> <a name="nameSetByPn" id="@wasend/core.Group.property.nameSetByPn"></a>

```typescript
public readonly nameSetByPn: string;
```

- *Type:* string

Phone number of who set the name.

---

##### `ownerJid`<sup>Required</sup> <a name="ownerJid" id="@wasend/core.Group.property.ownerJid"></a>

```typescript
public readonly ownerJid: string;
```

- *Type:* string

Owner JID.

---

##### `ownerPn`<sup>Required</sup> <a name="ownerPn" id="@wasend/core.Group.property.ownerPn"></a>

```typescript
public readonly ownerPn: string;
```

- *Type:* string

Owner phone number.

---

##### `participants`<sup>Required</sup> <a name="participants" id="@wasend/core.Group.property.participants"></a>

```typescript
public readonly participants: GroupParticipant[];
```

- *Type:* <a href="#@wasend/core.GroupParticipant">GroupParticipant</a>[]

Group participants.

---

##### `participantVersionId`<sup>Required</sup> <a name="participantVersionId" id="@wasend/core.Group.property.participantVersionId"></a>

```typescript
public readonly participantVersionId: string;
```

- *Type:* string

Participant version ID.

---

##### `topic`<sup>Required</sup> <a name="topic" id="@wasend/core.Group.property.topic"></a>

```typescript
public readonly topic: string;
```

- *Type:* string

Group topic/description.

---

##### `topicDeleted`<sup>Required</sup> <a name="topicDeleted" id="@wasend/core.Group.property.topicDeleted"></a>

```typescript
public readonly topicDeleted: boolean;
```

- *Type:* boolean

Whether the topic was deleted.

---

##### `topicId`<sup>Required</sup> <a name="topicId" id="@wasend/core.Group.property.topicId"></a>

```typescript
public readonly topicId: string;
```

- *Type:* string

Topic ID.

---

##### `topicSetAt`<sup>Required</sup> <a name="topicSetAt" id="@wasend/core.Group.property.topicSetAt"></a>

```typescript
public readonly topicSetAt: string;
```

- *Type:* string

When the topic was set.

---

##### `topicSetBy`<sup>Required</sup> <a name="topicSetBy" id="@wasend/core.Group.property.topicSetBy"></a>

```typescript
public readonly topicSetBy: string;
```

- *Type:* string

Who set the topic.

---

##### `topicSetByPn`<sup>Required</sup> <a name="topicSetByPn" id="@wasend/core.Group.property.topicSetByPn"></a>

```typescript
public readonly topicSetByPn: string;
```

- *Type:* string

Phone number of who set the topic.

---

### GroupParticipant <a name="GroupParticipant" id="@wasend/core.GroupParticipant"></a>

Group participant information.

#### Initializer <a name="Initializer" id="@wasend/core.GroupParticipant.Initializer"></a>

```typescript
import { GroupParticipant } from '@wasend/core'

const groupParticipant: GroupParticipant = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.GroupParticipant.property.isAdmin">isAdmin</a></code> | <code>boolean</code> | Whether the participant is an admin. |
| <code><a href="#@wasend/core.GroupParticipant.property.isSuperAdmin">isSuperAdmin</a></code> | <code>boolean</code> | Whether the participant is a super admin. |
| <code><a href="#@wasend/core.GroupParticipant.property.jid">jid</a></code> | <code>string</code> | Participant JID. |
| <code><a href="#@wasend/core.GroupParticipant.property.phoneNumber">phoneNumber</a></code> | <code>string</code> | Participant phone number. |
| <code><a href="#@wasend/core.GroupParticipant.property.addRequest">addRequest</a></code> | <code>any</code> | Add request information (if any). |
| <code><a href="#@wasend/core.GroupParticipant.property.displayName">displayName</a></code> | <code>string</code> | Participant display name. |
| <code><a href="#@wasend/core.GroupParticipant.property.error">error</a></code> | <code>number</code> | Error code (if any). |
| <code><a href="#@wasend/core.GroupParticipant.property.lid">lid</a></code> | <code>string</code> | Participant LID (if available). |

---

##### `isAdmin`<sup>Required</sup> <a name="isAdmin" id="@wasend/core.GroupParticipant.property.isAdmin"></a>

```typescript
public readonly isAdmin: boolean;
```

- *Type:* boolean

Whether the participant is an admin.

---

##### `isSuperAdmin`<sup>Required</sup> <a name="isSuperAdmin" id="@wasend/core.GroupParticipant.property.isSuperAdmin"></a>

```typescript
public readonly isSuperAdmin: boolean;
```

- *Type:* boolean

Whether the participant is a super admin.

---

##### `jid`<sup>Required</sup> <a name="jid" id="@wasend/core.GroupParticipant.property.jid"></a>

```typescript
public readonly jid: string;
```

- *Type:* string

Participant JID.

---

##### `phoneNumber`<sup>Required</sup> <a name="phoneNumber" id="@wasend/core.GroupParticipant.property.phoneNumber"></a>

```typescript
public readonly phoneNumber: string;
```

- *Type:* string

Participant phone number.

---

##### `addRequest`<sup>Optional</sup> <a name="addRequest" id="@wasend/core.GroupParticipant.property.addRequest"></a>

```typescript
public readonly addRequest: any;
```

- *Type:* any

Add request information (if any).

---

##### `displayName`<sup>Optional</sup> <a name="displayName" id="@wasend/core.GroupParticipant.property.displayName"></a>

```typescript
public readonly displayName: string;
```

- *Type:* string

Participant display name.

---

##### `error`<sup>Optional</sup> <a name="error" id="@wasend/core.GroupParticipant.property.error"></a>

```typescript
public readonly error: number;
```

- *Type:* number

Error code (if any).

---

##### `lid`<sup>Optional</sup> <a name="lid" id="@wasend/core.GroupParticipant.property.lid"></a>

```typescript
public readonly lid: string;
```

- *Type:* string

Participant LID (if available).

---

### GroupPictureResponse <a name="GroupPictureResponse" id="@wasend/core.GroupPictureResponse"></a>

Response for group picture operations.

#### Initializer <a name="Initializer" id="@wasend/core.GroupPictureResponse.Initializer"></a>

```typescript
import { GroupPictureResponse } from '@wasend/core'

const groupPictureResponse: GroupPictureResponse = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.GroupPictureResponse.property.url">url</a></code> | <code>string</code> | The URL of the group picture. |
| <code><a href="#@wasend/core.GroupPictureResponse.property.dimensions">dimensions</a></code> | <code>{[ key: string ]: string}</code> | The dimensions of the picture. |
| <code><a href="#@wasend/core.GroupPictureResponse.property.format">format</a></code> | <code>string</code> | The format of the picture (e.g., 'jpeg', 'png'). |
| <code><a href="#@wasend/core.GroupPictureResponse.property.size">size</a></code> | <code>number</code> | The size of the picture in bytes. |

---

##### `url`<sup>Required</sup> <a name="url" id="@wasend/core.GroupPictureResponse.property.url"></a>

```typescript
public readonly url: string;
```

- *Type:* string

The URL of the group picture.

---

##### `dimensions`<sup>Optional</sup> <a name="dimensions" id="@wasend/core.GroupPictureResponse.property.dimensions"></a>

```typescript
public readonly dimensions: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

The dimensions of the picture.

---

*Example*

```typescript
{
  "width": "800",
  "height": "600"
}
```


##### `format`<sup>Optional</sup> <a name="format" id="@wasend/core.GroupPictureResponse.property.format"></a>

```typescript
public readonly format: string;
```

- *Type:* string

The format of the picture (e.g., 'jpeg', 'png').

---

##### `size`<sup>Optional</sup> <a name="size" id="@wasend/core.GroupPictureResponse.property.size"></a>

```typescript
public readonly size: number;
```

- *Type:* number

The size of the picture in bytes.

---

### GroupSettings <a name="GroupSettings" id="@wasend/core.GroupSettings"></a>

Group settings.

#### Initializer <a name="Initializer" id="@wasend/core.GroupSettings.Initializer"></a>

```typescript
import { GroupSettings } from '@wasend/core'

const groupSettings: GroupSettings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.GroupSettings.property.infoAdminOnly">infoAdminOnly</a></code> | <code>boolean</code> | Whether only admins can edit group info. |
| <code><a href="#@wasend/core.GroupSettings.property.messagesAdminOnly">messagesAdminOnly</a></code> | <code>boolean</code> | Whether only admins can send messages. |
| <code><a href="#@wasend/core.GroupSettings.property.archived">archived</a></code> | <code>boolean</code> | Whether group is archived. |
| <code><a href="#@wasend/core.GroupSettings.property.muted">muted</a></code> | <code>boolean</code> | Whether group is muted. |
| <code><a href="#@wasend/core.GroupSettings.property.pinned">pinned</a></code> | <code>boolean</code> | Whether group is pinned. |

---

##### `infoAdminOnly`<sup>Required</sup> <a name="infoAdminOnly" id="@wasend/core.GroupSettings.property.infoAdminOnly"></a>

```typescript
public readonly infoAdminOnly: boolean;
```

- *Type:* boolean

Whether only admins can edit group info.

---

##### `messagesAdminOnly`<sup>Required</sup> <a name="messagesAdminOnly" id="@wasend/core.GroupSettings.property.messagesAdminOnly"></a>

```typescript
public readonly messagesAdminOnly: boolean;
```

- *Type:* boolean

Whether only admins can send messages.

---

##### `archived`<sup>Optional</sup> <a name="archived" id="@wasend/core.GroupSettings.property.archived"></a>

```typescript
public readonly archived: boolean;
```

- *Type:* boolean

Whether group is archived.

---

##### `muted`<sup>Optional</sup> <a name="muted" id="@wasend/core.GroupSettings.property.muted"></a>

```typescript
public readonly muted: boolean;
```

- *Type:* boolean

Whether group is muted.

---

##### `pinned`<sup>Optional</sup> <a name="pinned" id="@wasend/core.GroupSettings.property.pinned"></a>

```typescript
public readonly pinned: boolean;
```

- *Type:* boolean

Whether group is pinned.

---

### GrpcStatus <a name="GrpcStatus" id="@wasend/core.GrpcStatus"></a>

#### Initializer <a name="Initializer" id="@wasend/core.GrpcStatus.Initializer"></a>

```typescript
import { GrpcStatus } from '@wasend/core'

const grpcStatus: GrpcStatus = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.GrpcStatus.property.client">client</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@wasend/core.GrpcStatus.property.stream">stream</a></code> | <code>string</code> | *No description.* |

---

##### `client`<sup>Required</sup> <a name="client" id="@wasend/core.GrpcStatus.property.client"></a>

```typescript
public readonly client: string;
```

- *Type:* string

---

##### `stream`<sup>Required</sup> <a name="stream" id="@wasend/core.GrpcStatus.property.stream"></a>

```typescript
public readonly stream: string;
```

- *Type:* string

---

### JoinGroupRequest <a name="JoinGroupRequest" id="@wasend/core.JoinGroupRequest"></a>

Join group request.

#### Initializer <a name="Initializer" id="@wasend/core.JoinGroupRequest.Initializer"></a>

```typescript
import { JoinGroupRequest } from '@wasend/core'

const joinGroupRequest: JoinGroupRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.JoinGroupRequest.property.code">code</a></code> | <code>string</code> | Group code or invite URL. |

---

##### `code`<sup>Required</sup> <a name="code" id="@wasend/core.JoinGroupRequest.property.code"></a>

```typescript
public readonly code: string;
```

- *Type:* string

Group code or invite URL.

---

*Example*

```typescript
"https://chat.whatsapp.com/1234567890abcdef"
```


### JoinGroupResponse <a name="JoinGroupResponse" id="@wasend/core.JoinGroupResponse"></a>

Join group response.

#### Initializer <a name="Initializer" id="@wasend/core.JoinGroupResponse.Initializer"></a>

```typescript
import { JoinGroupResponse } from '@wasend/core'

const joinGroupResponse: JoinGroupResponse = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.JoinGroupResponse.property.id">id</a></code> | <code>string</code> | Group ID. |
| <code><a href="#@wasend/core.JoinGroupResponse.property.name">name</a></code> | <code>string</code> | Group name. |
| <code><a href="#@wasend/core.JoinGroupResponse.property.participantsCount">participantsCount</a></code> | <code>number</code> | Group participants count. |
| <code><a href="#@wasend/core.JoinGroupResponse.property.description">description</a></code> | <code>string</code> | Group description. |
| <code><a href="#@wasend/core.JoinGroupResponse.property.pictureUrl">pictureUrl</a></code> | <code>string</code> | Group picture URL. |

---

##### `id`<sup>Required</sup> <a name="id" id="@wasend/core.JoinGroupResponse.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Group ID.

---

##### `name`<sup>Required</sup> <a name="name" id="@wasend/core.JoinGroupResponse.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Group name.

---

##### `participantsCount`<sup>Required</sup> <a name="participantsCount" id="@wasend/core.JoinGroupResponse.property.participantsCount"></a>

```typescript
public readonly participantsCount: number;
```

- *Type:* number

Group participants count.

---

##### `description`<sup>Optional</sup> <a name="description" id="@wasend/core.JoinGroupResponse.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

Group description.

---

##### `pictureUrl`<sup>Optional</sup> <a name="pictureUrl" id="@wasend/core.JoinGroupResponse.property.pictureUrl"></a>

```typescript
public readonly pictureUrl: string;
```

- *Type:* string

Group picture URL.

---

### LinkPreviewRequest <a name="LinkPreviewRequest" id="@wasend/core.LinkPreviewRequest"></a>

Link preview request.

#### Initializer <a name="Initializer" id="@wasend/core.LinkPreviewRequest.Initializer"></a>

```typescript
import { LinkPreviewRequest } from '@wasend/core'

const linkPreviewRequest: LinkPreviewRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.LinkPreviewRequest.property.title">title</a></code> | <code>string</code> | The link title. |
| <code><a href="#@wasend/core.LinkPreviewRequest.property.description">description</a></code> | <code>string</code> | The link description. |
| <code><a href="#@wasend/core.LinkPreviewRequest.property.thumbnailUrl">thumbnailUrl</a></code> | <code>string</code> | The link thumbnail URL. |

---

##### `title`<sup>Required</sup> <a name="title" id="@wasend/core.LinkPreviewRequest.property.title"></a>

```typescript
public readonly title: string;
```

- *Type:* string

The link title.

---

##### `description`<sup>Optional</sup> <a name="description" id="@wasend/core.LinkPreviewRequest.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

The link description.

---

##### `thumbnailUrl`<sup>Optional</sup> <a name="thumbnailUrl" id="@wasend/core.LinkPreviewRequest.property.thumbnailUrl"></a>

```typescript
public readonly thumbnailUrl: string;
```

- *Type:* string

The link thumbnail URL.

---

### Message <a name="Message" id="@wasend/core.Message"></a>

Message data structure.

#### Initializer <a name="Initializer" id="@wasend/core.Message.Initializer"></a>

```typescript
import { Message } from '@wasend/core'

const message: Message = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.Message.property.content">content</a></code> | <code>string</code> | The content of the message. |
| <code><a href="#@wasend/core.Message.property.id">id</a></code> | <code>string</code> | Unique identifier for the message. |
| <code><a href="#@wasend/core.Message.property.sentAt">sentAt</a></code> | <code>string</code> | Timestamp when the message was sent (ISO string). |
| <code><a href="#@wasend/core.Message.property.status">status</a></code> | <code>string</code> | Message status. |
| <code><a href="#@wasend/core.Message.property.to">to</a></code> | <code>string</code> | The recipient of the message. |

---

##### `content`<sup>Required</sup> <a name="content" id="@wasend/core.Message.property.content"></a>

```typescript
public readonly content: string;
```

- *Type:* string

The content of the message.

---

##### `id`<sup>Required</sup> <a name="id" id="@wasend/core.Message.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Unique identifier for the message.

---

##### `sentAt`<sup>Required</sup> <a name="sentAt" id="@wasend/core.Message.property.sentAt"></a>

```typescript
public readonly sentAt: string;
```

- *Type:* string

Timestamp when the message was sent (ISO string).

---

##### `status`<sup>Required</sup> <a name="status" id="@wasend/core.Message.property.status"></a>

```typescript
public readonly status: string;
```

- *Type:* string

Message status.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.Message.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient of the message.

---

### MessageFileRequest <a name="MessageFileRequest" id="@wasend/core.MessageFileRequest"></a>

File message request.

#### Initializer <a name="Initializer" id="@wasend/core.MessageFileRequest.Initializer"></a>

```typescript
import { MessageFileRequest } from '@wasend/core'

const messageFileRequest: MessageFileRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.MessageFileRequest.property.content">content</a></code> | <code>string</code> | The content of the message. |
| <code><a href="#@wasend/core.MessageFileRequest.property.to">to</a></code> | <code>string</code> | The recipient of the message. |
| <code><a href="#@wasend/core.MessageFileRequest.property.fileName">fileName</a></code> | <code>string</code> | The file name. |
| <code><a href="#@wasend/core.MessageFileRequest.property.mimeType">mimeType</a></code> | <code>string</code> | The file mime type. |
| <code><a href="#@wasend/core.MessageFileRequest.property.data">data</a></code> | <code>string</code> | The file data in base64 format. |
| <code><a href="#@wasend/core.MessageFileRequest.property.url">url</a></code> | <code>string</code> | The file URL. |

---

##### `content`<sup>Required</sup> <a name="content" id="@wasend/core.MessageFileRequest.property.content"></a>

```typescript
public readonly content: string;
```

- *Type:* string

The content of the message.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.MessageFileRequest.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient of the message.

---

##### `fileName`<sup>Required</sup> <a name="fileName" id="@wasend/core.MessageFileRequest.property.fileName"></a>

```typescript
public readonly fileName: string;
```

- *Type:* string

The file name.

---

##### `mimeType`<sup>Required</sup> <a name="mimeType" id="@wasend/core.MessageFileRequest.property.mimeType"></a>

```typescript
public readonly mimeType: string;
```

- *Type:* string

The file mime type.

---

##### `data`<sup>Optional</sup> <a name="data" id="@wasend/core.MessageFileRequest.property.data"></a>

```typescript
public readonly data: string;
```

- *Type:* string

The file data in base64 format.

---

##### `url`<sup>Optional</sup> <a name="url" id="@wasend/core.MessageFileRequest.property.url"></a>

```typescript
public readonly url: string;
```

- *Type:* string

The file URL.

---

### MessageImageRequest <a name="MessageImageRequest" id="@wasend/core.MessageImageRequest"></a>

Image message request.

#### Initializer <a name="Initializer" id="@wasend/core.MessageImageRequest.Initializer"></a>

```typescript
import { MessageImageRequest } from '@wasend/core'

const messageImageRequest: MessageImageRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.MessageImageRequest.property.content">content</a></code> | <code>string</code> | The content of the message. |
| <code><a href="#@wasend/core.MessageImageRequest.property.to">to</a></code> | <code>string</code> | The recipient of the message. |
| <code><a href="#@wasend/core.MessageImageRequest.property.caption">caption</a></code> | <code>string</code> | The image caption. |
| <code><a href="#@wasend/core.MessageImageRequest.property.data">data</a></code> | <code>string</code> | The image data in base64 format. |
| <code><a href="#@wasend/core.MessageImageRequest.property.url">url</a></code> | <code>string</code> | The image URL. |

---

##### `content`<sup>Required</sup> <a name="content" id="@wasend/core.MessageImageRequest.property.content"></a>

```typescript
public readonly content: string;
```

- *Type:* string

The content of the message.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.MessageImageRequest.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient of the message.

---

##### `caption`<sup>Optional</sup> <a name="caption" id="@wasend/core.MessageImageRequest.property.caption"></a>

```typescript
public readonly caption: string;
```

- *Type:* string

The image caption.

---

##### `data`<sup>Optional</sup> <a name="data" id="@wasend/core.MessageImageRequest.property.data"></a>

```typescript
public readonly data: string;
```

- *Type:* string

The image data in base64 format.

---

##### `url`<sup>Optional</sup> <a name="url" id="@wasend/core.MessageImageRequest.property.url"></a>

```typescript
public readonly url: string;
```

- *Type:* string

The image URL.

---

### MessageLinkCustomPreviewRequest <a name="MessageLinkCustomPreviewRequest" id="@wasend/core.MessageLinkCustomPreviewRequest"></a>

Message with custom link preview request.

#### Initializer <a name="Initializer" id="@wasend/core.MessageLinkCustomPreviewRequest.Initializer"></a>

```typescript
import { MessageLinkCustomPreviewRequest } from '@wasend/core'

const messageLinkCustomPreviewRequest: MessageLinkCustomPreviewRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.MessageLinkCustomPreviewRequest.property.content">content</a></code> | <code>string</code> | The content of the message. |
| <code><a href="#@wasend/core.MessageLinkCustomPreviewRequest.property.to">to</a></code> | <code>string</code> | The recipient of the message. |
| <code><a href="#@wasend/core.MessageLinkCustomPreviewRequest.property.text">text</a></code> | <code>string</code> | The text content of the message. |
| <code><a href="#@wasend/core.MessageLinkCustomPreviewRequest.property.preview">preview</a></code> | <code><a href="#@wasend/core.LinkPreviewRequest">LinkPreviewRequest</a></code> | The link preview information. |

---

##### `content`<sup>Required</sup> <a name="content" id="@wasend/core.MessageLinkCustomPreviewRequest.property.content"></a>

```typescript
public readonly content: string;
```

- *Type:* string

The content of the message.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.MessageLinkCustomPreviewRequest.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient of the message.

---

##### `text`<sup>Required</sup> <a name="text" id="@wasend/core.MessageLinkCustomPreviewRequest.property.text"></a>

```typescript
public readonly text: string;
```

- *Type:* string

The text content of the message.

---

##### `preview`<sup>Required</sup> <a name="preview" id="@wasend/core.MessageLinkCustomPreviewRequest.property.preview"></a>

```typescript
public readonly preview: LinkPreviewRequest;
```

- *Type:* <a href="#@wasend/core.LinkPreviewRequest">LinkPreviewRequest</a>

The link preview information.

---

### MessageRequest <a name="MessageRequest" id="@wasend/core.MessageRequest"></a>

Message request structure.

#### Initializer <a name="Initializer" id="@wasend/core.MessageRequest.Initializer"></a>

```typescript
import { MessageRequest } from '@wasend/core'

const messageRequest: MessageRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.MessageRequest.property.content">content</a></code> | <code>string</code> | The content of the message. |
| <code><a href="#@wasend/core.MessageRequest.property.to">to</a></code> | <code>string</code> | The recipient of the message. |

---

##### `content`<sup>Required</sup> <a name="content" id="@wasend/core.MessageRequest.property.content"></a>

```typescript
public readonly content: string;
```

- *Type:* string

The content of the message.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.MessageRequest.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient of the message.

---

### MessageTextRequest <a name="MessageTextRequest" id="@wasend/core.MessageTextRequest"></a>

Text message request.

#### Initializer <a name="Initializer" id="@wasend/core.MessageTextRequest.Initializer"></a>

```typescript
import { MessageTextRequest } from '@wasend/core'

const messageTextRequest: MessageTextRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.MessageTextRequest.property.content">content</a></code> | <code>string</code> | The content of the message. |
| <code><a href="#@wasend/core.MessageTextRequest.property.to">to</a></code> | <code>string</code> | The recipient of the message. |
| <code><a href="#@wasend/core.MessageTextRequest.property.text">text</a></code> | <code>string</code> | The text content of the message. |

---

##### `content`<sup>Required</sup> <a name="content" id="@wasend/core.MessageTextRequest.property.content"></a>

```typescript
public readonly content: string;
```

- *Type:* string

The content of the message.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.MessageTextRequest.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient of the message.

---

##### `text`<sup>Required</sup> <a name="text" id="@wasend/core.MessageTextRequest.property.text"></a>

```typescript
public readonly text: string;
```

- *Type:* string

The text content of the message.

---

### MessageVideoRequest <a name="MessageVideoRequest" id="@wasend/core.MessageVideoRequest"></a>

Video message request.

#### Initializer <a name="Initializer" id="@wasend/core.MessageVideoRequest.Initializer"></a>

```typescript
import { MessageVideoRequest } from '@wasend/core'

const messageVideoRequest: MessageVideoRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.MessageVideoRequest.property.content">content</a></code> | <code>string</code> | The content of the message. |
| <code><a href="#@wasend/core.MessageVideoRequest.property.to">to</a></code> | <code>string</code> | The recipient of the message. |
| <code><a href="#@wasend/core.MessageVideoRequest.property.caption">caption</a></code> | <code>string</code> | The video caption. |
| <code><a href="#@wasend/core.MessageVideoRequest.property.data">data</a></code> | <code>string</code> | The video data in base64 format. |
| <code><a href="#@wasend/core.MessageVideoRequest.property.url">url</a></code> | <code>string</code> | The video URL. |

---

##### `content`<sup>Required</sup> <a name="content" id="@wasend/core.MessageVideoRequest.property.content"></a>

```typescript
public readonly content: string;
```

- *Type:* string

The content of the message.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.MessageVideoRequest.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient of the message.

---

##### `caption`<sup>Optional</sup> <a name="caption" id="@wasend/core.MessageVideoRequest.property.caption"></a>

```typescript
public readonly caption: string;
```

- *Type:* string

The video caption.

---

##### `data`<sup>Optional</sup> <a name="data" id="@wasend/core.MessageVideoRequest.property.data"></a>

```typescript
public readonly data: string;
```

- *Type:* string

The video data in base64 format.

---

##### `url`<sup>Optional</sup> <a name="url" id="@wasend/core.MessageVideoRequest.property.url"></a>

```typescript
public readonly url: string;
```

- *Type:* string

The video URL.

---

### MessageVoiceRequest <a name="MessageVoiceRequest" id="@wasend/core.MessageVoiceRequest"></a>

Voice message request.

#### Initializer <a name="Initializer" id="@wasend/core.MessageVoiceRequest.Initializer"></a>

```typescript
import { MessageVoiceRequest } from '@wasend/core'

const messageVoiceRequest: MessageVoiceRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.MessageVoiceRequest.property.content">content</a></code> | <code>string</code> | The content of the message. |
| <code><a href="#@wasend/core.MessageVoiceRequest.property.to">to</a></code> | <code>string</code> | The recipient of the message. |
| <code><a href="#@wasend/core.MessageVoiceRequest.property.data">data</a></code> | <code>string</code> | The voice message data in base64 format. |
| <code><a href="#@wasend/core.MessageVoiceRequest.property.duration">duration</a></code> | <code>number</code> | The voice message duration in seconds. |
| <code><a href="#@wasend/core.MessageVoiceRequest.property.url">url</a></code> | <code>string</code> | The voice message URL. |

---

##### `content`<sup>Required</sup> <a name="content" id="@wasend/core.MessageVoiceRequest.property.content"></a>

```typescript
public readonly content: string;
```

- *Type:* string

The content of the message.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.MessageVoiceRequest.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient of the message.

---

##### `data`<sup>Optional</sup> <a name="data" id="@wasend/core.MessageVoiceRequest.property.data"></a>

```typescript
public readonly data: string;
```

- *Type:* string

The voice message data in base64 format.

---

##### `duration`<sup>Optional</sup> <a name="duration" id="@wasend/core.MessageVoiceRequest.property.duration"></a>

```typescript
public readonly duration: number;
```

- *Type:* number

The voice message duration in seconds.

---

##### `url`<sup>Optional</sup> <a name="url" id="@wasend/core.MessageVoiceRequest.property.url"></a>

```typescript
public readonly url: string;
```

- *Type:* string

The voice message URL.

---

### NowebConfig <a name="NowebConfig" id="@wasend/core.NowebConfig"></a>

#### Initializer <a name="Initializer" id="@wasend/core.NowebConfig.Initializer"></a>

```typescript
import { NowebConfig } from '@wasend/core'

const nowebConfig: NowebConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.NowebConfig.property.markOnline">markOnline</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.NowebConfig.property.store">store</a></code> | <code><a href="#@wasend/core.NowebStoreConfig">NowebStoreConfig</a></code> | *No description.* |

---

##### `markOnline`<sup>Required</sup> <a name="markOnline" id="@wasend/core.NowebConfig.property.markOnline"></a>

```typescript
public readonly markOnline: boolean;
```

- *Type:* boolean

---

##### `store`<sup>Required</sup> <a name="store" id="@wasend/core.NowebConfig.property.store"></a>

```typescript
public readonly store: NowebStoreConfig;
```

- *Type:* <a href="#@wasend/core.NowebStoreConfig">NowebStoreConfig</a>

---

### NowebStoreConfig <a name="NowebStoreConfig" id="@wasend/core.NowebStoreConfig"></a>

#### Initializer <a name="Initializer" id="@wasend/core.NowebStoreConfig.Initializer"></a>

```typescript
import { NowebStoreConfig } from '@wasend/core'

const nowebStoreConfig: NowebStoreConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.NowebStoreConfig.property.enabled">enabled</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.NowebStoreConfig.property.fullSync">fullSync</a></code> | <code>boolean</code> | *No description.* |

---

##### `enabled`<sup>Required</sup> <a name="enabled" id="@wasend/core.NowebStoreConfig.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

---

##### `fullSync`<sup>Required</sup> <a name="fullSync" id="@wasend/core.NowebStoreConfig.property.fullSync"></a>

```typescript
public readonly fullSync: boolean;
```

- *Type:* boolean

---

### ParticipantsRequest <a name="ParticipantsRequest" id="@wasend/core.ParticipantsRequest"></a>

Participants request.

#### Initializer <a name="Initializer" id="@wasend/core.ParticipantsRequest.Initializer"></a>

```typescript
import { ParticipantsRequest } from '@wasend/core'

const participantsRequest: ParticipantsRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.ParticipantsRequest.property.participants">participants</a></code> | <code>string[]</code> | List of participant IDs. |
| <code><a href="#@wasend/core.ParticipantsRequest.property.notify">notify</a></code> | <code>boolean</code> | Whether to notify participants. |

---

##### `participants`<sup>Required</sup> <a name="participants" id="@wasend/core.ParticipantsRequest.property.participants"></a>

```typescript
public readonly participants: string[];
```

- *Type:* string[]

List of participant IDs.

---

*Example*

```typescript
["+919545251359", "+919545251360"]
```


##### `notify`<sup>Optional</sup> <a name="notify" id="@wasend/core.ParticipantsRequest.property.notify"></a>

```typescript
public readonly notify: boolean;
```

- *Type:* boolean
- *Default:* true

Whether to notify participants.

---

### ProfilePictureRequest <a name="ProfilePictureRequest" id="@wasend/core.ProfilePictureRequest"></a>

Profile picture request.

#### Initializer <a name="Initializer" id="@wasend/core.ProfilePictureRequest.Initializer"></a>

```typescript
import { ProfilePictureRequest } from '@wasend/core'

const profilePictureRequest: ProfilePictureRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.ProfilePictureRequest.property.url">url</a></code> | <code>string</code> | Picture URL. |
| <code><a href="#@wasend/core.ProfilePictureRequest.property.cropToSquare">cropToSquare</a></code> | <code>boolean</code> | Whether to crop the picture to a square. |
| <code><a href="#@wasend/core.ProfilePictureRequest.property.format">format</a></code> | <code>string</code> | Picture format (optional). |

---

##### `url`<sup>Required</sup> <a name="url" id="@wasend/core.ProfilePictureRequest.property.url"></a>

```typescript
public readonly url: string;
```

- *Type:* string

Picture URL.

---

##### `cropToSquare`<sup>Optional</sup> <a name="cropToSquare" id="@wasend/core.ProfilePictureRequest.property.cropToSquare"></a>

```typescript
public readonly cropToSquare: boolean;
```

- *Type:* boolean
- *Default:* true

Whether to crop the picture to a square.

---

##### `format`<sup>Optional</sup> <a name="format" id="@wasend/core.ProfilePictureRequest.property.format"></a>

```typescript
public readonly format: string;
```

- *Type:* string
- *Default:* "jpeg"

Picture format (optional).

---

### ProfilePictureResponse <a name="ProfilePictureResponse" id="@wasend/core.ProfilePictureResponse"></a>

Profile picture response.

#### Initializer <a name="Initializer" id="@wasend/core.ProfilePictureResponse.Initializer"></a>

```typescript
import { ProfilePictureResponse } from '@wasend/core'

const profilePictureResponse: ProfilePictureResponse = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.ProfilePictureResponse.property.url">url</a></code> | <code>string</code> | The URL of the profile picture. |
| <code><a href="#@wasend/core.ProfilePictureResponse.property.dimensions">dimensions</a></code> | <code>{[ key: string ]: string}</code> | The dimensions of the picture. |
| <code><a href="#@wasend/core.ProfilePictureResponse.property.format">format</a></code> | <code>string</code> | The format of the picture (e.g., 'jpeg', 'png'). |
| <code><a href="#@wasend/core.ProfilePictureResponse.property.size">size</a></code> | <code>number</code> | The size of the picture in bytes. |

---

##### `url`<sup>Required</sup> <a name="url" id="@wasend/core.ProfilePictureResponse.property.url"></a>

```typescript
public readonly url: string;
```

- *Type:* string

The URL of the profile picture.

---

##### `dimensions`<sup>Optional</sup> <a name="dimensions" id="@wasend/core.ProfilePictureResponse.property.dimensions"></a>

```typescript
public readonly dimensions: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

The dimensions of the picture.

---

*Example*

```typescript
{
  "width": "800",
  "height": "600"
}
```


##### `format`<sup>Optional</sup> <a name="format" id="@wasend/core.ProfilePictureResponse.property.format"></a>

```typescript
public readonly format: string;
```

- *Type:* string

The format of the picture (e.g., 'jpeg', 'png').

---

##### `size`<sup>Optional</sup> <a name="size" id="@wasend/core.ProfilePictureResponse.property.size"></a>

```typescript
public readonly size: number;
```

- *Type:* number

The size of the picture in bytes.

---

### QRCodeResponse <a name="QRCodeResponse" id="@wasend/core.QRCodeResponse"></a>

QR code response.

#### Initializer <a name="Initializer" id="@wasend/core.QRCodeResponse.Initializer"></a>

```typescript
import { QRCodeResponse } from '@wasend/core'

const qRCodeResponse: QRCodeResponse = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.QRCodeResponse.property.data">data</a></code> | <code>string</code> | QR code data. |

---

##### `data`<sup>Required</sup> <a name="data" id="@wasend/core.QRCodeResponse.property.data"></a>

```typescript
public readonly data: string;
```

- *Type:* string

QR code data.

---

### SendRequest <a name="SendRequest" id="@wasend/core.SendRequest"></a>

Send message request interface.

#### Initializer <a name="Initializer" id="@wasend/core.SendRequest.Initializer"></a>

```typescript
import { SendRequest } from '@wasend/core'

const sendRequest: SendRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SendRequest.property.session">session</a></code> | <code>string</code> | The session ID. |
| <code><a href="#@wasend/core.SendRequest.property.to">to</a></code> | <code>string</code> | The recipient's phone number or group JID. |
| <code><a href="#@wasend/core.SendRequest.property.audioUrl">audioUrl</a></code> | <code>string</code> | The audio URL. |
| <code><a href="#@wasend/core.SendRequest.property.documentUrl">documentUrl</a></code> | <code>string</code> | The document URL. |
| <code><a href="#@wasend/core.SendRequest.property.filename">filename</a></code> | <code>string</code> | The filename for the media. |
| <code><a href="#@wasend/core.SendRequest.property.imageUrl">imageUrl</a></code> | <code>string</code> | The image URL. |
| <code><a href="#@wasend/core.SendRequest.property.mimetype">mimetype</a></code> | <code>string</code> | The MIME type of the media. |
| <code><a href="#@wasend/core.SendRequest.property.preview">preview</a></code> | <code>{[ key: string ]: string}</code> | The link preview information. |
| <code><a href="#@wasend/core.SendRequest.property.text">text</a></code> | <code>string</code> | The message text or caption. |
| <code><a href="#@wasend/core.SendRequest.property.videoUrl">videoUrl</a></code> | <code>string</code> | The video URL. |

---

##### `session`<sup>Required</sup> <a name="session" id="@wasend/core.SendRequest.property.session"></a>

```typescript
public readonly session: string;
```

- *Type:* string

The session ID.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.SendRequest.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient's phone number or group JID.

---

*Example*

```typescript
"+1234567890" or "1234567890-12345678@g.us"
```


##### `audioUrl`<sup>Optional</sup> <a name="audioUrl" id="@wasend/core.SendRequest.property.audioUrl"></a>

```typescript
public readonly audioUrl: string;
```

- *Type:* string

The audio URL.

---

*Example*

```typescript
"https://example.com/audio.mp3"
```


##### `documentUrl`<sup>Optional</sup> <a name="documentUrl" id="@wasend/core.SendRequest.property.documentUrl"></a>

```typescript
public readonly documentUrl: string;
```

- *Type:* string

The document URL.

---

*Example*

```typescript
"https://example.com/document.pdf"
```


##### `filename`<sup>Optional</sup> <a name="filename" id="@wasend/core.SendRequest.property.filename"></a>

```typescript
public readonly filename: string;
```

- *Type:* string

The filename for the media.

---

*Example*

```typescript
"custom_image.jpg"
```


##### `imageUrl`<sup>Optional</sup> <a name="imageUrl" id="@wasend/core.SendRequest.property.imageUrl"></a>

```typescript
public readonly imageUrl: string;
```

- *Type:* string

The image URL.

---

*Example*

```typescript
"https://example.com/image.jpg"
```


##### `mimetype`<sup>Optional</sup> <a name="mimetype" id="@wasend/core.SendRequest.property.mimetype"></a>

```typescript
public readonly mimetype: string;
```

- *Type:* string

The MIME type of the media.

---

*Example*

```typescript
"image/jpeg"
```


##### `preview`<sup>Optional</sup> <a name="preview" id="@wasend/core.SendRequest.property.preview"></a>

```typescript
public readonly preview: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

The link preview information.

---

##### `text`<sup>Optional</sup> <a name="text" id="@wasend/core.SendRequest.property.text"></a>

```typescript
public readonly text: string;
```

- *Type:* string

The message text or caption.

---

*Example*

```typescript
"Hello from WASend!"
```


##### `videoUrl`<sup>Optional</sup> <a name="videoUrl" id="@wasend/core.SendRequest.property.videoUrl"></a>

```typescript
public readonly videoUrl: string;
```

- *Type:* string

The video URL.

---

*Example*

```typescript
"https://example.com/video.mp4"
```


### SendSeenRequest <a name="SendSeenRequest" id="@wasend/core.SendSeenRequest"></a>

Send seen request.

#### Initializer <a name="Initializer" id="@wasend/core.SendSeenRequest.Initializer"></a>

```typescript
import { SendSeenRequest } from '@wasend/core'

const sendSeenRequest: SendSeenRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SendSeenRequest.property.session">session</a></code> | <code>string</code> | The session ID. |
| <code><a href="#@wasend/core.SendSeenRequest.property.to">to</a></code> | <code>string</code> | The recipient's phone number or group JID. |
| <code><a href="#@wasend/core.SendSeenRequest.property.messageId">messageId</a></code> | <code>string</code> | The message ID to mark as seen. |

---

##### `session`<sup>Required</sup> <a name="session" id="@wasend/core.SendSeenRequest.property.session"></a>

```typescript
public readonly session: string;
```

- *Type:* string

The session ID.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.SendSeenRequest.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient's phone number or group JID.

---

*Example*

```typescript
"+1234567890" or "1234567890-12345678@g.us"
```


##### `messageId`<sup>Required</sup> <a name="messageId" id="@wasend/core.SendSeenRequest.property.messageId"></a>

```typescript
public readonly messageId: string;
```

- *Type:* string

The message ID to mark as seen.

---

### Session <a name="Session" id="@wasend/core.Session"></a>

Session information from createSession and other operations.

#### Initializer <a name="Initializer" id="@wasend/core.Session.Initializer"></a>

```typescript
import { Session } from '@wasend/core'

const session: Session = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.Session.property.createdAt">createdAt</a></code> | <code>string</code> | Creation timestamp. |
| <code><a href="#@wasend/core.Session.property.enableAccountProtection">enableAccountProtection</a></code> | <code>boolean</code> | Session configuration flags. |
| <code><a href="#@wasend/core.Session.property.enableMessageLogging">enableMessageLogging</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.Session.property.enableWebhook">enableWebhook</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.Session.property.id">id</a></code> | <code>string</code> | MongoDB ID of the session. |
| <code><a href="#@wasend/core.Session.property.phoneNumber">phoneNumber</a></code> | <code>string</code> | Phone number associated with the session. |
| <code><a href="#@wasend/core.Session.property.sessionName">sessionName</a></code> | <code>string</code> | Name of the session. |
| <code><a href="#@wasend/core.Session.property.uniqueSessionId">uniqueSessionId</a></code> | <code>string</code> | Unique session identifier. |
| <code><a href="#@wasend/core.Session.property.updatedAt">updatedAt</a></code> | <code>string</code> | Last update timestamp. |
| <code><a href="#@wasend/core.Session.property.userId">userId</a></code> | <code>string</code> | User ID who owns the session. |
| <code><a href="#@wasend/core.Session.property.webhookUrl">webhookUrl</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@wasend/core.Session.property.config">config</a></code> | <code><a href="#@wasend/core.SessionConfig">SessionConfig</a></code> | Session configuration. |
| <code><a href="#@wasend/core.Session.property.engine">engine</a></code> | <code><a href="#@wasend/core.EngineStatus">EngineStatus</a></code> | Engine status information. |
| <code><a href="#@wasend/core.Session.property.name">name</a></code> | <code>string</code> | Name of the session. |
| <code><a href="#@wasend/core.Session.property.status">status</a></code> | <code>string</code> | Current status of the session. |

---

##### `createdAt`<sup>Required</sup> <a name="createdAt" id="@wasend/core.Session.property.createdAt"></a>

```typescript
public readonly createdAt: string;
```

- *Type:* string

Creation timestamp.

---

##### `enableAccountProtection`<sup>Required</sup> <a name="enableAccountProtection" id="@wasend/core.Session.property.enableAccountProtection"></a>

```typescript
public readonly enableAccountProtection: boolean;
```

- *Type:* boolean

Session configuration flags.

---

##### `enableMessageLogging`<sup>Required</sup> <a name="enableMessageLogging" id="@wasend/core.Session.property.enableMessageLogging"></a>

```typescript
public readonly enableMessageLogging: boolean;
```

- *Type:* boolean

---

##### `enableWebhook`<sup>Required</sup> <a name="enableWebhook" id="@wasend/core.Session.property.enableWebhook"></a>

```typescript
public readonly enableWebhook: boolean;
```

- *Type:* boolean

---

##### `id`<sup>Required</sup> <a name="id" id="@wasend/core.Session.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

MongoDB ID of the session.

---

##### `phoneNumber`<sup>Required</sup> <a name="phoneNumber" id="@wasend/core.Session.property.phoneNumber"></a>

```typescript
public readonly phoneNumber: string;
```

- *Type:* string

Phone number associated with the session.

---

##### `sessionName`<sup>Required</sup> <a name="sessionName" id="@wasend/core.Session.property.sessionName"></a>

```typescript
public readonly sessionName: string;
```

- *Type:* string

Name of the session.

---

##### `uniqueSessionId`<sup>Required</sup> <a name="uniqueSessionId" id="@wasend/core.Session.property.uniqueSessionId"></a>

```typescript
public readonly uniqueSessionId: string;
```

- *Type:* string

Unique session identifier.

---

##### `updatedAt`<sup>Required</sup> <a name="updatedAt" id="@wasend/core.Session.property.updatedAt"></a>

```typescript
public readonly updatedAt: string;
```

- *Type:* string

Last update timestamp.

---

##### `userId`<sup>Required</sup> <a name="userId" id="@wasend/core.Session.property.userId"></a>

```typescript
public readonly userId: string;
```

- *Type:* string

User ID who owns the session.

---

##### `webhookUrl`<sup>Optional</sup> <a name="webhookUrl" id="@wasend/core.Session.property.webhookUrl"></a>

```typescript
public readonly webhookUrl: string;
```

- *Type:* string

---

##### `config`<sup>Required</sup> <a name="config" id="@wasend/core.Session.property.config"></a>

```typescript
public readonly config: SessionConfig;
```

- *Type:* <a href="#@wasend/core.SessionConfig">SessionConfig</a>

Session configuration.

---

##### `engine`<sup>Required</sup> <a name="engine" id="@wasend/core.Session.property.engine"></a>

```typescript
public readonly engine: EngineStatus;
```

- *Type:* <a href="#@wasend/core.EngineStatus">EngineStatus</a>

Engine status information.

---

##### `name`<sup>Required</sup> <a name="name" id="@wasend/core.Session.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the session.

---

##### `status`<sup>Required</sup> <a name="status" id="@wasend/core.Session.property.status"></a>

```typescript
public readonly status: string;
```

- *Type:* string

Current status of the session.

---

### SessionConfig <a name="SessionConfig" id="@wasend/core.SessionConfig"></a>

Session configuration.

#### Initializer <a name="Initializer" id="@wasend/core.SessionConfig.Initializer"></a>

```typescript
import { SessionConfig } from '@wasend/core'

const sessionConfig: SessionConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SessionConfig.property.debug">debug</a></code> | <code>boolean</code> | Debug mode. |
| <code><a href="#@wasend/core.SessionConfig.property.metadata">metadata</a></code> | <code><a href="#@wasend/core.SessionMetadata">SessionMetadata</a></code> | User metadata. |
| <code><a href="#@wasend/core.SessionConfig.property.noweb">noweb</a></code> | <code><a href="#@wasend/core.NowebConfig">NowebConfig</a></code> | Noweb configuration. |
| <code><a href="#@wasend/core.SessionConfig.property.proxy">proxy</a></code> | <code>any</code> | Proxy configuration. |
| <code><a href="#@wasend/core.SessionConfig.property.webhooks">webhooks</a></code> | <code>any[]</code> | Webhook configurations. |

---

##### `debug`<sup>Required</sup> <a name="debug" id="@wasend/core.SessionConfig.property.debug"></a>

```typescript
public readonly debug: boolean;
```

- *Type:* boolean

Debug mode.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="@wasend/core.SessionConfig.property.metadata"></a>

```typescript
public readonly metadata: SessionMetadata;
```

- *Type:* <a href="#@wasend/core.SessionMetadata">SessionMetadata</a>

User metadata.

---

##### `noweb`<sup>Required</sup> <a name="noweb" id="@wasend/core.SessionConfig.property.noweb"></a>

```typescript
public readonly noweb: NowebConfig;
```

- *Type:* <a href="#@wasend/core.NowebConfig">NowebConfig</a>

Noweb configuration.

---

##### `proxy`<sup>Required</sup> <a name="proxy" id="@wasend/core.SessionConfig.property.proxy"></a>

```typescript
public readonly proxy: any;
```

- *Type:* any

Proxy configuration.

---

##### `webhooks`<sup>Required</sup> <a name="webhooks" id="@wasend/core.SessionConfig.property.webhooks"></a>

```typescript
public readonly webhooks: any[];
```

- *Type:* any[]

Webhook configurations.

---

### SessionCreateRequest <a name="SessionCreateRequest" id="@wasend/core.SessionCreateRequest"></a>

Session creation request body.

#### Initializer <a name="Initializer" id="@wasend/core.SessionCreateRequest.Initializer"></a>

```typescript
import { SessionCreateRequest } from '@wasend/core'

const sessionCreateRequest: SessionCreateRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SessionCreateRequest.property.phoneNumber">phoneNumber</a></code> | <code>string</code> | Phone number for the WhatsApp session. |
| <code><a href="#@wasend/core.SessionCreateRequest.property.sessionName">sessionName</a></code> | <code>string</code> | Name of the session. |
| <code><a href="#@wasend/core.SessionCreateRequest.property.enableAccountProtection">enableAccountProtection</a></code> | <code>boolean</code> | Enable account protection features. |
| <code><a href="#@wasend/core.SessionCreateRequest.property.enableMessageLogging">enableMessageLogging</a></code> | <code>boolean</code> | Enable message logging. |
| <code><a href="#@wasend/core.SessionCreateRequest.property.enableWebhook">enableWebhook</a></code> | <code>boolean</code> | Enable webhook notifications. |
| <code><a href="#@wasend/core.SessionCreateRequest.property.webhookUrl">webhookUrl</a></code> | <code>string</code> | Webhook URL for notifications Required if enableWebhook is true. |

---

##### `phoneNumber`<sup>Required</sup> <a name="phoneNumber" id="@wasend/core.SessionCreateRequest.property.phoneNumber"></a>

```typescript
public readonly phoneNumber: string;
```

- *Type:* string

Phone number for the WhatsApp session.

---

##### `sessionName`<sup>Required</sup> <a name="sessionName" id="@wasend/core.SessionCreateRequest.property.sessionName"></a>

```typescript
public readonly sessionName: string;
```

- *Type:* string

Name of the session.

---

##### `enableAccountProtection`<sup>Optional</sup> <a name="enableAccountProtection" id="@wasend/core.SessionCreateRequest.property.enableAccountProtection"></a>

```typescript
public readonly enableAccountProtection: boolean;
```

- *Type:* boolean
- *Default:* false

Enable account protection features.

---

##### `enableMessageLogging`<sup>Optional</sup> <a name="enableMessageLogging" id="@wasend/core.SessionCreateRequest.property.enableMessageLogging"></a>

```typescript
public readonly enableMessageLogging: boolean;
```

- *Type:* boolean
- *Default:* false

Enable message logging.

---

##### `enableWebhook`<sup>Optional</sup> <a name="enableWebhook" id="@wasend/core.SessionCreateRequest.property.enableWebhook"></a>

```typescript
public readonly enableWebhook: boolean;
```

- *Type:* boolean
- *Default:* false

Enable webhook notifications.

---

##### `webhookUrl`<sup>Optional</sup> <a name="webhookUrl" id="@wasend/core.SessionCreateRequest.property.webhookUrl"></a>

```typescript
public readonly webhookUrl: string;
```

- *Type:* string

Webhook URL for notifications Required if enableWebhook is true.

---

### SessionDetails <a name="SessionDetails" id="@wasend/core.SessionDetails"></a>

Session details.

#### Initializer <a name="Initializer" id="@wasend/core.SessionDetails.Initializer"></a>

```typescript
import { SessionDetails } from '@wasend/core'

const sessionDetails: SessionDetails = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SessionDetails.property.createdAt">createdAt</a></code> | <code>string</code> | Creation timestamp. |
| <code><a href="#@wasend/core.SessionDetails.property.enableAccountProtection">enableAccountProtection</a></code> | <code>boolean</code> | Session configuration flags. |
| <code><a href="#@wasend/core.SessionDetails.property.enableMessageLogging">enableMessageLogging</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.SessionDetails.property.enableWebhook">enableWebhook</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.SessionDetails.property.id">id</a></code> | <code>string</code> | MongoDB ID of the session. |
| <code><a href="#@wasend/core.SessionDetails.property.phoneNumber">phoneNumber</a></code> | <code>string</code> | Phone number associated with the session. |
| <code><a href="#@wasend/core.SessionDetails.property.sessionName">sessionName</a></code> | <code>string</code> | Name of the session. |
| <code><a href="#@wasend/core.SessionDetails.property.uniqueSessionId">uniqueSessionId</a></code> | <code>string</code> | Unique session identifier. |
| <code><a href="#@wasend/core.SessionDetails.property.updatedAt">updatedAt</a></code> | <code>string</code> | Last update timestamp. |
| <code><a href="#@wasend/core.SessionDetails.property.userId">userId</a></code> | <code>string</code> | User ID who owns the session. |
| <code><a href="#@wasend/core.SessionDetails.property.webhookUrl">webhookUrl</a></code> | <code>string</code> | *No description.* |

---

##### `createdAt`<sup>Required</sup> <a name="createdAt" id="@wasend/core.SessionDetails.property.createdAt"></a>

```typescript
public readonly createdAt: string;
```

- *Type:* string

Creation timestamp.

---

##### `enableAccountProtection`<sup>Required</sup> <a name="enableAccountProtection" id="@wasend/core.SessionDetails.property.enableAccountProtection"></a>

```typescript
public readonly enableAccountProtection: boolean;
```

- *Type:* boolean

Session configuration flags.

---

##### `enableMessageLogging`<sup>Required</sup> <a name="enableMessageLogging" id="@wasend/core.SessionDetails.property.enableMessageLogging"></a>

```typescript
public readonly enableMessageLogging: boolean;
```

- *Type:* boolean

---

##### `enableWebhook`<sup>Required</sup> <a name="enableWebhook" id="@wasend/core.SessionDetails.property.enableWebhook"></a>

```typescript
public readonly enableWebhook: boolean;
```

- *Type:* boolean

---

##### `id`<sup>Required</sup> <a name="id" id="@wasend/core.SessionDetails.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

MongoDB ID of the session.

---

##### `phoneNumber`<sup>Required</sup> <a name="phoneNumber" id="@wasend/core.SessionDetails.property.phoneNumber"></a>

```typescript
public readonly phoneNumber: string;
```

- *Type:* string

Phone number associated with the session.

---

##### `sessionName`<sup>Required</sup> <a name="sessionName" id="@wasend/core.SessionDetails.property.sessionName"></a>

```typescript
public readonly sessionName: string;
```

- *Type:* string

Name of the session.

---

##### `uniqueSessionId`<sup>Required</sup> <a name="uniqueSessionId" id="@wasend/core.SessionDetails.property.uniqueSessionId"></a>

```typescript
public readonly uniqueSessionId: string;
```

- *Type:* string

Unique session identifier.

---

##### `updatedAt`<sup>Required</sup> <a name="updatedAt" id="@wasend/core.SessionDetails.property.updatedAt"></a>

```typescript
public readonly updatedAt: string;
```

- *Type:* string

Last update timestamp.

---

##### `userId`<sup>Required</sup> <a name="userId" id="@wasend/core.SessionDetails.property.userId"></a>

```typescript
public readonly userId: string;
```

- *Type:* string

User ID who owns the session.

---

##### `webhookUrl`<sup>Optional</sup> <a name="webhookUrl" id="@wasend/core.SessionDetails.property.webhookUrl"></a>

```typescript
public readonly webhookUrl: string;
```

- *Type:* string

---

### SessionListItem <a name="SessionListItem" id="@wasend/core.SessionListItem"></a>

Session information from getAllSessions.

#### Initializer <a name="Initializer" id="@wasend/core.SessionListItem.Initializer"></a>

```typescript
import { SessionListItem } from '@wasend/core'

const sessionListItem: SessionListItem = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SessionListItem.property.downstream">downstream</a></code> | <code><a href="#@wasend/core.DownstreamInfo">DownstreamInfo</a></code> | Downstream connection information. |
| <code><a href="#@wasend/core.SessionListItem.property.session">session</a></code> | <code><a href="#@wasend/core.SessionDetails">SessionDetails</a></code> | Session details. |

---

##### `downstream`<sup>Required</sup> <a name="downstream" id="@wasend/core.SessionListItem.property.downstream"></a>

```typescript
public readonly downstream: DownstreamInfo;
```

- *Type:* <a href="#@wasend/core.DownstreamInfo">DownstreamInfo</a>

Downstream connection information.

---

##### `session`<sup>Required</sup> <a name="session" id="@wasend/core.SessionListItem.property.session"></a>

```typescript
public readonly session: SessionDetails;
```

- *Type:* <a href="#@wasend/core.SessionDetails">SessionDetails</a>

Session details.

---

### SessionMetadata <a name="SessionMetadata" id="@wasend/core.SessionMetadata"></a>

#### Initializer <a name="Initializer" id="@wasend/core.SessionMetadata.Initializer"></a>

```typescript
import { SessionMetadata } from '@wasend/core'

const sessionMetadata: SessionMetadata = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SessionMetadata.property.userEmail">userEmail</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@wasend/core.SessionMetadata.property.userId">userId</a></code> | <code>string</code> | *No description.* |

---

##### `userEmail`<sup>Required</sup> <a name="userEmail" id="@wasend/core.SessionMetadata.property.userEmail"></a>

```typescript
public readonly userEmail: string;
```

- *Type:* string

---

##### `userId`<sup>Required</sup> <a name="userId" id="@wasend/core.SessionMetadata.property.userId"></a>

```typescript
public readonly userId: string;
```

- *Type:* string

---

### SettingsSecurityChangeInfo <a name="SettingsSecurityChangeInfo" id="@wasend/core.SettingsSecurityChangeInfo"></a>

Settings security change info.

#### Initializer <a name="Initializer" id="@wasend/core.SettingsSecurityChangeInfo.Initializer"></a>

```typescript
import { SettingsSecurityChangeInfo } from '@wasend/core'

const settingsSecurityChangeInfo: SettingsSecurityChangeInfo = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SettingsSecurityChangeInfo.property.enabled">enabled</a></code> | <code>boolean</code> | Whether the setting is enabled. |
| <code><a href="#@wasend/core.SettingsSecurityChangeInfo.property.changedAt">changedAt</a></code> | <code>string</code> | When the setting was last changed. |
| <code><a href="#@wasend/core.SettingsSecurityChangeInfo.property.changedBy">changedBy</a></code> | <code>string</code> | Who changed the setting. |

---

##### `enabled`<sup>Required</sup> <a name="enabled" id="@wasend/core.SettingsSecurityChangeInfo.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

Whether the setting is enabled.

---

##### `changedAt`<sup>Optional</sup> <a name="changedAt" id="@wasend/core.SettingsSecurityChangeInfo.property.changedAt"></a>

```typescript
public readonly changedAt: string;
```

- *Type:* string

When the setting was last changed.

---

##### `changedBy`<sup>Optional</sup> <a name="changedBy" id="@wasend/core.SettingsSecurityChangeInfo.property.changedBy"></a>

```typescript
public readonly changedBy: string;
```

- *Type:* string

Who changed the setting.

---

### SubjectRequest <a name="SubjectRequest" id="@wasend/core.SubjectRequest"></a>

Subject request.

#### Initializer <a name="Initializer" id="@wasend/core.SubjectRequest.Initializer"></a>

```typescript
import { SubjectRequest } from '@wasend/core'

const subjectRequest: SubjectRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SubjectRequest.property.subject">subject</a></code> | <code>string</code> | Group subject/name. |

---

##### `subject`<sup>Required</sup> <a name="subject" id="@wasend/core.SubjectRequest.property.subject"></a>

```typescript
public readonly subject: string;
```

- *Type:* string

Group subject/name.

---

### WAMessage <a name="WAMessage" id="@wasend/core.WAMessage"></a>

WhatsApp message response.

#### Initializer <a name="Initializer" id="@wasend/core.WAMessage.Initializer"></a>

```typescript
import { WAMessage } from '@wasend/core'

const wAMessage: WAMessage = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.WAMessage.property.content">content</a></code> | <code>string</code> | The message content. |
| <code><a href="#@wasend/core.WAMessage.property.fromMe">fromMe</a></code> | <code>boolean</code> | Whether the message is from me. |
| <code><a href="#@wasend/core.WAMessage.property.id">id</a></code> | <code>string</code> | The message ID. |
| <code><a href="#@wasend/core.WAMessage.property.recipient">recipient</a></code> | <code>string</code> | The message recipient. |
| <code><a href="#@wasend/core.WAMessage.property.sender">sender</a></code> | <code>string</code> | The message sender. |
| <code><a href="#@wasend/core.WAMessage.property.status">status</a></code> | <code>string</code> | The message status. |
| <code><a href="#@wasend/core.WAMessage.property.timestamp">timestamp</a></code> | <code>string</code> | The message timestamp. |
| <code><a href="#@wasend/core.WAMessage.property.to">to</a></code> | <code>string</code> | The recipient's phone number or group JID. |
| <code><a href="#@wasend/core.WAMessage.property.type">type</a></code> | <code>string</code> | The message type. |

---

##### `content`<sup>Required</sup> <a name="content" id="@wasend/core.WAMessage.property.content"></a>

```typescript
public readonly content: string;
```

- *Type:* string

The message content.

---

##### `fromMe`<sup>Required</sup> <a name="fromMe" id="@wasend/core.WAMessage.property.fromMe"></a>

```typescript
public readonly fromMe: boolean;
```

- *Type:* boolean

Whether the message is from me.

---

##### `id`<sup>Required</sup> <a name="id" id="@wasend/core.WAMessage.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

The message ID.

---

##### `recipient`<sup>Required</sup> <a name="recipient" id="@wasend/core.WAMessage.property.recipient"></a>

```typescript
public readonly recipient: string;
```

- *Type:* string

The message recipient.

---

##### `sender`<sup>Required</sup> <a name="sender" id="@wasend/core.WAMessage.property.sender"></a>

```typescript
public readonly sender: string;
```

- *Type:* string

The message sender.

---

##### `status`<sup>Required</sup> <a name="status" id="@wasend/core.WAMessage.property.status"></a>

```typescript
public readonly status: string;
```

- *Type:* string

The message status.

---

##### `timestamp`<sup>Required</sup> <a name="timestamp" id="@wasend/core.WAMessage.property.timestamp"></a>

```typescript
public readonly timestamp: string;
```

- *Type:* string

The message timestamp.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.WAMessage.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient's phone number or group JID.

---

##### `type`<sup>Required</sup> <a name="type" id="@wasend/core.WAMessage.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

The message type.

---

### WANumberExistResult <a name="WANumberExistResult" id="@wasend/core.WANumberExistResult"></a>

WhatsApp number existence check result.

#### Initializer <a name="Initializer" id="@wasend/core.WANumberExistResult.Initializer"></a>

```typescript
import { WANumberExistResult } from '@wasend/core'

const wANumberExistResult: WANumberExistResult = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.WANumberExistResult.property.exists">exists</a></code> | <code>boolean</code> | Whether the number exists on WhatsApp. |
| <code><a href="#@wasend/core.WANumberExistResult.property.phone">phone</a></code> | <code>string</code> | The phone number that was checked. |
| <code><a href="#@wasend/core.WANumberExistResult.property.jid">jid</a></code> | <code>string</code> | The JID of the contact if it exists. |

---

##### `exists`<sup>Required</sup> <a name="exists" id="@wasend/core.WANumberExistResult.property.exists"></a>

```typescript
public readonly exists: boolean;
```

- *Type:* boolean

Whether the number exists on WhatsApp.

---

##### `phone`<sup>Required</sup> <a name="phone" id="@wasend/core.WANumberExistResult.property.phone"></a>

```typescript
public readonly phone: string;
```

- *Type:* string

The phone number that was checked.

---

##### `jid`<sup>Optional</sup> <a name="jid" id="@wasend/core.WANumberExistResult.property.jid"></a>

```typescript
public readonly jid: string;
```

- *Type:* string

The JID of the contact if it exists.

---

### WasendConfig <a name="WasendConfig" id="@wasend/core.WasendConfig"></a>

Configuration options for the Wasend SDK.

#### Initializer <a name="Initializer" id="@wasend/core.WasendConfig.Initializer"></a>

```typescript
import { WasendConfig } from '@wasend/core'

const wasendConfig: WasendConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.WasendConfig.property.apiKey">apiKey</a></code> | <code>string</code> | The API key for authentication. |
| <code><a href="#@wasend/core.WasendConfig.property.baseUrl">baseUrl</a></code> | <code>string</code> | The base URL for the API (optional). |
| <code><a href="#@wasend/core.WasendConfig.property.timeout">timeout</a></code> | <code>number</code> | Request timeout in milliseconds. |

---

##### `apiKey`<sup>Required</sup> <a name="apiKey" id="@wasend/core.WasendConfig.property.apiKey"></a>

```typescript
public readonly apiKey: string;
```

- *Type:* string

The API key for authentication.

---

##### `baseUrl`<sup>Optional</sup> <a name="baseUrl" id="@wasend/core.WasendConfig.property.baseUrl"></a>

```typescript
public readonly baseUrl: string;
```

- *Type:* string
- *Default:* https://api.wasend.dev

The base URL for the API (optional).

---

##### `timeout`<sup>Optional</sup> <a name="timeout" id="@wasend/core.WasendConfig.property.timeout"></a>

```typescript
public readonly timeout: number;
```

- *Type:* number
- *Default:* 30000

Request timeout in milliseconds.

---

### WasendConfigInfo <a name="WasendConfigInfo" id="@wasend/core.WasendConfigInfo"></a>

Configuration information (without sensitive data).

#### Initializer <a name="Initializer" id="@wasend/core.WasendConfigInfo.Initializer"></a>

```typescript
import { WasendConfigInfo } from '@wasend/core'

const wasendConfigInfo: WasendConfigInfo = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.WasendConfigInfo.property.baseUrl">baseUrl</a></code> | <code>string</code> | The base URL for the API. |
| <code><a href="#@wasend/core.WasendConfigInfo.property.timeout">timeout</a></code> | <code>number</code> | Request timeout in milliseconds. |

---

##### `baseUrl`<sup>Optional</sup> <a name="baseUrl" id="@wasend/core.WasendConfigInfo.property.baseUrl"></a>

```typescript
public readonly baseUrl: string;
```

- *Type:* string

The base URL for the API.

---

##### `timeout`<sup>Optional</sup> <a name="timeout" id="@wasend/core.WasendConfigInfo.property.timeout"></a>

```typescript
public readonly timeout: number;
```

- *Type:* number

Request timeout in milliseconds.

---

## Classes <a name="Classes" id="Classes"></a>

### WasendClient <a name="WasendClient" id="@wasend/core.WasendClient"></a>

Main Wasend SDK Client.

This class provides access to the Wasend API for sending messages,
managing contacts, and other messaging operations.

*Example*

```typescript
const client = new WasendClient({
  apiKey: 'your-api-key'
});

const result = await client.sendMessage({
  to: '+1234567890',
  content: 'Hello, World!'
});
```


#### Initializers <a name="Initializers" id="@wasend/core.WasendClient.Initializer"></a>

```typescript
import { WasendClient } from '@wasend/core'

new WasendClient(config: WasendConfig)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.WasendClient.Initializer.parameter.config">config</a></code> | <code><a href="#@wasend/core.WasendConfig">WasendConfig</a></code> | - Configuration options for the client. |

---

##### `config`<sup>Required</sup> <a name="config" id="@wasend/core.WasendClient.Initializer.parameter.config"></a>

- *Type:* <a href="#@wasend/core.WasendConfig">WasendConfig</a>

Configuration options for the client.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@wasend/core.WasendClient.addGroupParticipants">addGroupParticipants</a></code> | Add participants to group. |
| <code><a href="#@wasend/core.WasendClient.checkContactExists">checkContactExists</a></code> | Check if a phone number is registered in WhatsApp. |
| <code><a href="#@wasend/core.WasendClient.createGroup">createGroup</a></code> | Create a new group. |
| <code><a href="#@wasend/core.WasendClient.createSession">createSession</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.deleteGroupPicture">deleteGroupPicture</a></code> | Delete group picture. |
| <code><a href="#@wasend/core.WasendClient.deleteSession">deleteSession</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.demoteGroupParticipants">demoteGroupParticipants</a></code> | Demote participants from admin. |
| <code><a href="#@wasend/core.WasendClient.getContact">getContact</a></code> | Get contact basic info. |
| <code><a href="#@wasend/core.WasendClient.getContactProfilePicture">getContactProfilePicture</a></code> | Get contact's profile picture URL. |
| <code><a href="#@wasend/core.WasendClient.getContacts">getContacts</a></code> | Get all contacts. |
| <code><a href="#@wasend/core.WasendClient.getGroup">getGroup</a></code> | Get a specific group. |
| <code><a href="#@wasend/core.WasendClient.getGroupInfoAdminOnly">getGroupInfoAdminOnly</a></code> | Get group info admin only setting. |
| <code><a href="#@wasend/core.WasendClient.getGroupInviteCode">getGroupInviteCode</a></code> | Get group invite code. |
| <code><a href="#@wasend/core.WasendClient.getGroupJoinInfo">getGroupJoinInfo</a></code> | Get group join info. |
| <code><a href="#@wasend/core.WasendClient.getGroupMessagesAdminOnly">getGroupMessagesAdminOnly</a></code> | Get group messages admin only setting. |
| <code><a href="#@wasend/core.WasendClient.getGroupParticipants">getGroupParticipants</a></code> | Get group participants. |
| <code><a href="#@wasend/core.WasendClient.getGroupPicture">getGroupPicture</a></code> | Get group picture. |
| <code><a href="#@wasend/core.WasendClient.getGroups">getGroups</a></code> | Get all groups. |
| <code><a href="#@wasend/core.WasendClient.getGroupsCount">getGroupsCount</a></code> | Get groups count. |
| <code><a href="#@wasend/core.WasendClient.getMessage">getMessage</a></code> | Get message by ID. |
| <code><a href="#@wasend/core.WasendClient.joinGroup">joinGroup</a></code> | Join a group. |
| <code><a href="#@wasend/core.WasendClient.leaveGroup">leaveGroup</a></code> | Leave a group. |
| <code><a href="#@wasend/core.WasendClient.processMessage">processMessage</a></code> | Utility method to process a message with proper timing and typing indicators This follows WhatsApp's guidelines to avoid being flagged as spam. |
| <code><a href="#@wasend/core.WasendClient.promoteGroupParticipants">promoteGroupParticipants</a></code> | Promote participants to admin. |
| <code><a href="#@wasend/core.WasendClient.removeGroupParticipants">removeGroupParticipants</a></code> | Remove participants from group. |
| <code><a href="#@wasend/core.WasendClient.restartSession">restartSession</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.retrieveAccount">retrieveAccount</a></code> | Get account information. |
| <code><a href="#@wasend/core.WasendClient.retrieveAllSessions">retrieveAllSessions</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.retrieveConfig">retrieveConfig</a></code> | Get the current configuration. |
| <code><a href="#@wasend/core.WasendClient.retrieveQRCode">retrieveQRCode</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.retrieveSessionInfo">retrieveSessionInfo</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.revokeGroupInviteCode">revokeGroupInviteCode</a></code> | Revoke group invite code. |
| <code><a href="#@wasend/core.WasendClient.send">send</a></code> | Send a message using the unified send endpoint. |
| <code><a href="#@wasend/core.WasendClient.sendFile">sendFile</a></code> | Send a file message. |
| <code><a href="#@wasend/core.WasendClient.sendImage">sendImage</a></code> | Send an image message. |
| <code><a href="#@wasend/core.WasendClient.sendLinkCustomPreview">sendLinkCustomPreview</a></code> | Send a text message with custom link preview. |
| <code><a href="#@wasend/core.WasendClient.sendMessage">sendMessage</a></code> | Send a message to a recipient. |
| <code><a href="#@wasend/core.WasendClient.sendSeen">sendSeen</a></code> | Mark a message as seen. |
| <code><a href="#@wasend/core.WasendClient.sendText">sendText</a></code> | Send a text message. |
| <code><a href="#@wasend/core.WasendClient.sendVideo">sendVideo</a></code> | Send a video message. |
| <code><a href="#@wasend/core.WasendClient.sendVoice">sendVoice</a></code> | Send a voice message. |
| <code><a href="#@wasend/core.WasendClient.setGroupDescription">setGroupDescription</a></code> | Set group description. |
| <code><a href="#@wasend/core.WasendClient.setGroupInfoAdminOnly">setGroupInfoAdminOnly</a></code> | Set group info admin only setting. |
| <code><a href="#@wasend/core.WasendClient.setGroupMessagesAdminOnly">setGroupMessagesAdminOnly</a></code> | Set group messages admin only setting. |
| <code><a href="#@wasend/core.WasendClient.setGroupPicture">setGroupPicture</a></code> | Set group picture. |
| <code><a href="#@wasend/core.WasendClient.setGroupSubject">setGroupSubject</a></code> | Set group subject. |
| <code><a href="#@wasend/core.WasendClient.startSession">startSession</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.startTyping">startTyping</a></code> | Start typing indicator. |
| <code><a href="#@wasend/core.WasendClient.stopSession">stopSession</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.stopTyping">stopTyping</a></code> | Stop typing indicator. |

---

##### `addGroupParticipants` <a name="addGroupParticipants" id="@wasend/core.WasendClient.addGroupParticipants"></a>

```typescript
public addGroupParticipants(sessionId: string, groupId: string, request: ParticipantsRequest): void
```

Add participants to group.

*Example*

```typescript
curl -X POST 'http://localhost:3001/{sessionId}/groups/{groupId}/participants/add' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "participants": ["+1234567890", "+0987654321"],
    "notify": true
  }'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.addGroupParticipants.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.addGroupParticipants.parameter.groupId"></a>

- *Type:* string

The group ID (full JID, e.g., 1234567890-12345678@g.us).

---

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.addGroupParticipants.parameter.request"></a>

- *Type:* <a href="#@wasend/core.ParticipantsRequest">ParticipantsRequest</a>

The participants request.

Participant IDs should be phone numbers (e.g., +1234567890) or full JIDs.

---

##### `checkContactExists` <a name="checkContactExists" id="@wasend/core.WasendClient.checkContactExists"></a>

```typescript
public checkContactExists(sessionId: string, params: CheckContactExistsQueryParams): WANumberExistResult
```

Check if a phone number is registered in WhatsApp.

*Example*

```typescript
curl -X GET 'http://localhost:3001/contacts/check-exists?session={sessionId}&phone=1213213213' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.checkContactExists.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `params`<sup>Required</sup> <a name="params" id="@wasend/core.WasendClient.checkContactExists.parameter.params"></a>

- *Type:* <a href="#@wasend/core.CheckContactExistsQueryParams">CheckContactExistsQueryParams</a>

The check exists query parameters.

'phone' should be a number without '+' (e.g., 1213213213).

---

##### `createGroup` <a name="createGroup" id="@wasend/core.WasendClient.createGroup"></a>

```typescript
public createGroup(sessionId: string, request: CreateGroupRequest): Group
```

Create a new group.

*Example*

```typescript
curl -X POST 'http://localhost:3001/{sessionId}/groups' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "name": "My Group",
    "participants": [{"id": "+1234567890"}],
    "description": "Group description"
  }'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.createGroup.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.createGroup.parameter.request"></a>

- *Type:* <a href="#@wasend/core.CreateGroupRequest">CreateGroupRequest</a>

The group creation request.

---

##### `createSession` <a name="createSession" id="@wasend/core.WasendClient.createSession"></a>

```typescript
public createSession(request: SessionCreateRequest): Session
```

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.createSession.parameter.request"></a>

- *Type:* <a href="#@wasend/core.SessionCreateRequest">SessionCreateRequest</a>

---

##### `deleteGroupPicture` <a name="deleteGroupPicture" id="@wasend/core.WasendClient.deleteGroupPicture"></a>

```typescript
public deleteGroupPicture(sessionId: string, groupId: string): void
```

Delete group picture.

*Example*

```typescript
curl -X DELETE 'http://localhost:3001/{sessionId}/groups/{groupId}/picture' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.deleteGroupPicture.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.deleteGroupPicture.parameter.groupId"></a>

- *Type:* string

The group ID.

---

##### `deleteSession` <a name="deleteSession" id="@wasend/core.WasendClient.deleteSession"></a>

```typescript
public deleteSession(sessionId: string): void
```

###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.deleteSession.parameter.sessionId"></a>

- *Type:* string

---

##### `demoteGroupParticipants` <a name="demoteGroupParticipants" id="@wasend/core.WasendClient.demoteGroupParticipants"></a>

```typescript
public demoteGroupParticipants(sessionId: string, groupId: string, request: ParticipantsRequest): void
```

Demote participants from admin.

*Example*

```typescript
curl -X POST 'http://localhost:3001/{sessionId}/groups/{groupId}/admin/demote' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "participants": ["+1234567890", "+0987654321"],
    "notify": true
  }'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.demoteGroupParticipants.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.demoteGroupParticipants.parameter.groupId"></a>

- *Type:* string

The group ID (full JID, e.g., 1234567890-12345678@g.us).

---

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.demoteGroupParticipants.parameter.request"></a>

- *Type:* <a href="#@wasend/core.ParticipantsRequest">ParticipantsRequest</a>

The participants request.

Participant IDs should be phone numbers (e.g., +1234567890) or full JIDs.

---

##### `getContact` <a name="getContact" id="@wasend/core.WasendClient.getContact"></a>

```typescript
public getContact(sessionId: string, params: GetContactQueryParams): Contact
```

Get contact basic info.

*Example*

```typescript
curl -X GET 'http://localhost:3001/contacts?session={sessionId}&contactId=+11111111111' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.getContact.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `params`<sup>Required</sup> <a name="params" id="@wasend/core.WasendClient.getContact.parameter.params"></a>

- *Type:* <a href="#@wasend/core.GetContactQueryParams">GetContactQueryParams</a>

The contact query parameters.

Use a phone number for 'contactId' (e.g., +1234567890) or a full JID.

---

##### `getContactProfilePicture` <a name="getContactProfilePicture" id="@wasend/core.WasendClient.getContactProfilePicture"></a>

```typescript
public getContactProfilePicture(sessionId: string, params: GetProfilePictureQueryParams): ProfilePictureResponse
```

Get contact's profile picture URL.

*Example*

```typescript
curl -X GET 'http://localhost:3001/contacts/profile-picture?session={sessionId}&contactId=+11111111111&refresh=false' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.getContactProfilePicture.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `params`<sup>Required</sup> <a name="params" id="@wasend/core.WasendClient.getContactProfilePicture.parameter.params"></a>

- *Type:* <a href="#@wasend/core.GetProfilePictureQueryParams">GetProfilePictureQueryParams</a>

The profile picture query parameters.

Use a phone number for 'contactId' (e.g., +1234567890) or a full JID.

---

##### `getContacts` <a name="getContacts" id="@wasend/core.WasendClient.getContacts"></a>

```typescript
public getContacts(sessionId: string, params?: GetContactsQueryParams): Contact[]
```

Get all contacts.

*Example*

```typescript
curl -X GET 'http://localhost:3001/contacts/all?session={sessionId}&sortBy=name&sortOrder=asc&limit=10&offset=0' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.getContacts.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `params`<sup>Optional</sup> <a name="params" id="@wasend/core.WasendClient.getContacts.parameter.params"></a>

- *Type:* <a href="#@wasend/core.GetContactsQueryParams">GetContactsQueryParams</a>

Optional query parameters.

---

##### `getGroup` <a name="getGroup" id="@wasend/core.WasendClient.getGroup"></a>

```typescript
public getGroup(sessionId: string, groupId: string): Group
```

Get a specific group.

*Example*

```typescript
curl -X GET 'http://localhost:3001/{sessionId}/groups/{groupId}' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.getGroup.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.getGroup.parameter.groupId"></a>

- *Type:* string

The group ID.

---

##### `getGroupInfoAdminOnly` <a name="getGroupInfoAdminOnly" id="@wasend/core.WasendClient.getGroupInfoAdminOnly"></a>

```typescript
public getGroupInfoAdminOnly(sessionId: string, groupId: string): SettingsSecurityChangeInfo
```

Get group info admin only setting.

*Example*

```typescript
curl -X GET 'http://localhost:3001/{sessionId}/groups/{groupId}/settings/security/info-admin-only' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.getGroupInfoAdminOnly.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.getGroupInfoAdminOnly.parameter.groupId"></a>

- *Type:* string

The group ID.

---

##### `getGroupInviteCode` <a name="getGroupInviteCode" id="@wasend/core.WasendClient.getGroupInviteCode"></a>

```typescript
public getGroupInviteCode(sessionId: string, groupId: string): string
```

Get group invite code.

*Example*

```typescript
curl -X GET 'http://localhost:3001/{sessionId}/groups/{groupId}/invite-code' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.getGroupInviteCode.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.getGroupInviteCode.parameter.groupId"></a>

- *Type:* string

The group ID.

---

##### `getGroupJoinInfo` <a name="getGroupJoinInfo" id="@wasend/core.WasendClient.getGroupJoinInfo"></a>

```typescript
public getGroupJoinInfo(sessionId: string, code: string): Group
```

Get group join info.

*Example*

```typescript
curl -X GET 'http://localhost:3001/{sessionId}/groups/join-info?code=https://chat.whatsapp.com/1234567890abcdef' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.getGroupJoinInfo.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `code`<sup>Required</sup> <a name="code" id="@wasend/core.WasendClient.getGroupJoinInfo.parameter.code"></a>

- *Type:* string

Group code or invite URL.

---

##### `getGroupMessagesAdminOnly` <a name="getGroupMessagesAdminOnly" id="@wasend/core.WasendClient.getGroupMessagesAdminOnly"></a>

```typescript
public getGroupMessagesAdminOnly(sessionId: string, groupId: string): SettingsSecurityChangeInfo
```

Get group messages admin only setting.

*Example*

```typescript
curl -X GET 'http://localhost:3001/{sessionId}/groups/{groupId}/settings/security/messages-admin-only' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.getGroupMessagesAdminOnly.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.getGroupMessagesAdminOnly.parameter.groupId"></a>

- *Type:* string

The group ID.

---

##### `getGroupParticipants` <a name="getGroupParticipants" id="@wasend/core.WasendClient.getGroupParticipants"></a>

```typescript
public getGroupParticipants(sessionId: string, groupId: string): GroupParticipant[]
```

Get group participants.

*Example*

```typescript
curl -X GET 'http://localhost:3001/{sessionId}/groups/{groupId}/participants' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.getGroupParticipants.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.getGroupParticipants.parameter.groupId"></a>

- *Type:* string

The group ID.

---

##### `getGroupPicture` <a name="getGroupPicture" id="@wasend/core.WasendClient.getGroupPicture"></a>

```typescript
public getGroupPicture(sessionId: string, groupId: string, refresh?: boolean): GroupPictureResponse
```

Get group picture.

*Example*

```typescript
curl -X GET 'http://localhost:3001/{sessionId}/groups/{groupId}/picture?refresh=true' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.getGroupPicture.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.getGroupPicture.parameter.groupId"></a>

- *Type:* string

The group ID.

---

###### `refresh`<sup>Optional</sup> <a name="refresh" id="@wasend/core.WasendClient.getGroupPicture.parameter.refresh"></a>

- *Type:* boolean

Whether to refresh the picture from server.

---

##### `getGroups` <a name="getGroups" id="@wasend/core.WasendClient.getGroups"></a>

```typescript
public getGroups(sessionId: string, params?: GetGroupsQueryParams): Group[]
```

Get all groups.

*Example*

```typescript
curl -X GET 'http://localhost:3001/{sessionId}/groups?sortBy=creation&sortOrder=desc&limit=50&offset=0' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.getGroups.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `params`<sup>Optional</sup> <a name="params" id="@wasend/core.WasendClient.getGroups.parameter.params"></a>

- *Type:* <a href="#@wasend/core.GetGroupsQueryParams">GetGroupsQueryParams</a>

Optional query parameters.

---

##### `getGroupsCount` <a name="getGroupsCount" id="@wasend/core.WasendClient.getGroupsCount"></a>

```typescript
public getGroupsCount(sessionId: string): CountResponse
```

Get groups count.

*Example*

```typescript
curl -X GET 'http://localhost:3001/{sessionId}/groups/count' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.getGroupsCount.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

##### `getMessage` <a name="getMessage" id="@wasend/core.WasendClient.getMessage"></a>

```typescript
public getMessage(messageId: string): ApiResponse
```

Get message by ID.

###### `messageId`<sup>Required</sup> <a name="messageId" id="@wasend/core.WasendClient.getMessage.parameter.messageId"></a>

- *Type:* string

The ID of the message to retrieve.

---

##### `joinGroup` <a name="joinGroup" id="@wasend/core.WasendClient.joinGroup"></a>

```typescript
public joinGroup(sessionId: string, request: JoinGroupRequest): JoinGroupResponse
```

Join a group.

*Example*

```typescript
curl -X POST 'http://localhost:3001/{sessionId}/groups/join' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "code": "https://chat.whatsapp.com/1234567890abcdef"
  }'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.joinGroup.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.joinGroup.parameter.request"></a>

- *Type:* <a href="#@wasend/core.JoinGroupRequest">JoinGroupRequest</a>

The join group request.

---

##### `leaveGroup` <a name="leaveGroup" id="@wasend/core.WasendClient.leaveGroup"></a>

```typescript
public leaveGroup(sessionId: string, groupId: string): void
```

Leave a group.

*Example*

```typescript
curl -X POST 'http://localhost:3001/{sessionId}/groups/{groupId}/leave' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.leaveGroup.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.leaveGroup.parameter.groupId"></a>

- *Type:* string

The group ID.

---

##### `processMessage` <a name="processMessage" id="@wasend/core.WasendClient.processMessage"></a>

```typescript
public processMessage(request: SendRequest, options?: {[ key: string ]: string}): WAMessage
```

Utility method to process a message with proper timing and typing indicators This follows WhatsApp's guidelines to avoid being flagged as spam.

*Example*

```typescript
// Send a text message with proper processing
const message = await client.processMessage({
  session: "sessionId",
  to: "+1234567890",
  text: "Hello, World!"
});

// Send an image with caption and proper processing
const imageMessage = await client.processMessage({
  session: "sessionId",
  to: "+1234567890",
  imageUrl: "https://example.com/image.jpg",
  text: "Check out this image!"
});
```


###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.processMessage.parameter.request"></a>

- *Type:* <a href="#@wasend/core.SendRequest">SendRequest</a>

The send request to process.

For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.

---

###### `options`<sup>Optional</sup> <a name="options" id="@wasend/core.WasendClient.processMessage.parameter.options"></a>

- *Type:* {[ key: string ]: string}

Optional configuration for the message processing.

---

##### `promoteGroupParticipants` <a name="promoteGroupParticipants" id="@wasend/core.WasendClient.promoteGroupParticipants"></a>

```typescript
public promoteGroupParticipants(sessionId: string, groupId: string, request: ParticipantsRequest): void
```

Promote participants to admin.

*Example*

```typescript
curl -X POST 'http://localhost:3001/{sessionId}/groups/{groupId}/admin/promote' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "participants": ["+1234567890", "+0987654321"],
    "notify": true
  }'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.promoteGroupParticipants.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.promoteGroupParticipants.parameter.groupId"></a>

- *Type:* string

The group ID (full JID, e.g., 1234567890-12345678@g.us).

---

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.promoteGroupParticipants.parameter.request"></a>

- *Type:* <a href="#@wasend/core.ParticipantsRequest">ParticipantsRequest</a>

The participants request.

Participant IDs should be phone numbers (e.g., +1234567890) or full JIDs.

---

##### `removeGroupParticipants` <a name="removeGroupParticipants" id="@wasend/core.WasendClient.removeGroupParticipants"></a>

```typescript
public removeGroupParticipants(sessionId: string, groupId: string, request: ParticipantsRequest): void
```

Remove participants from group.

*Example*

```typescript
curl -X POST 'http://localhost:3001/{sessionId}/groups/{groupId}/participants/remove' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "participants": ["+1234567890", "+0987654321"],
    "notify": true
  }'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.removeGroupParticipants.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.removeGroupParticipants.parameter.groupId"></a>

- *Type:* string

The group ID (full JID, e.g., 1234567890-12345678@g.us).

---

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.removeGroupParticipants.parameter.request"></a>

- *Type:* <a href="#@wasend/core.ParticipantsRequest">ParticipantsRequest</a>

The participants request.

Participant IDs should be phone numbers (e.g., +1234567890) or full JIDs.

---

##### `restartSession` <a name="restartSession" id="@wasend/core.WasendClient.restartSession"></a>

```typescript
public restartSession(sessionId: string): Session
```

###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.restartSession.parameter.sessionId"></a>

- *Type:* string

---

##### `retrieveAccount` <a name="retrieveAccount" id="@wasend/core.WasendClient.retrieveAccount"></a>

```typescript
public retrieveAccount(): ApiResponse
```

Get account information.

##### `retrieveAllSessions` <a name="retrieveAllSessions" id="@wasend/core.WasendClient.retrieveAllSessions"></a>

```typescript
public retrieveAllSessions(): GetAllSessionsResponse
```

##### `retrieveConfig` <a name="retrieveConfig" id="@wasend/core.WasendClient.retrieveConfig"></a>

```typescript
public retrieveConfig(): WasendConfigInfo
```

Get the current configuration.

##### `retrieveQRCode` <a name="retrieveQRCode" id="@wasend/core.WasendClient.retrieveQRCode"></a>

```typescript
public retrieveQRCode(sessionId: string): QRCodeResponse
```

###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.retrieveQRCode.parameter.sessionId"></a>

- *Type:* string

---

##### `retrieveSessionInfo` <a name="retrieveSessionInfo" id="@wasend/core.WasendClient.retrieveSessionInfo"></a>

```typescript
public retrieveSessionInfo(sessionId: string): Session
```

###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.retrieveSessionInfo.parameter.sessionId"></a>

- *Type:* string

---

##### `revokeGroupInviteCode` <a name="revokeGroupInviteCode" id="@wasend/core.WasendClient.revokeGroupInviteCode"></a>

```typescript
public revokeGroupInviteCode(sessionId: string, groupId: string): string
```

Revoke group invite code.

*Example*

```typescript
curl -X POST 'http://localhost:3001/{sessionId}/groups/{groupId}/invite-code/revoke' \
  -H 'Authorization: Bearer {apiKey}'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.revokeGroupInviteCode.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.revokeGroupInviteCode.parameter.groupId"></a>

- *Type:* string

The group ID.

---

##### `send` <a name="send" id="@wasend/core.WasendClient.send"></a>

```typescript
public send(request: SendRequest): WAMessage
```

Send a message using the unified send endpoint.

*Example*

```typescript
// Send a text message
const textMessage = await client.send({
  session: "sessionId",
  to: "+1234567890",
  text: "Hello from WASend!"
});

// Send an image
const imageMessage = await client.send({
  session: "sessionId",
  to: "+1234567890",
  imageUrl: "https://example.com/image.jpg",
  text: "Check out this image!",
  mimetype: "image/jpeg"
});

// Send a video
const videoMessage = await client.send({
  session: "sessionId",
  to: "+1234567890",
  videoUrl: "https://example.com/video.mp4",
  text: "Check out this video!",
  mimetype: "video/mp4"
});

// Send a document
const documentMessage = await client.send({
  session: "sessionId",
  to: "+1234567890",
  documentUrl: "https://example.com/document.pdf",
  filename: "document.pdf",
  mimetype: "application/pdf"
});

// Send an audio message
const audioMessage = await client.send({
  session: "sessionId",
  to: "+1234567890",
  audioUrl: "https://example.com/audio.mp3",
  mimetype: "audio/mpeg"
});
```


###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.send.parameter.request"></a>

- *Type:* <a href="#@wasend/core.SendRequest">SendRequest</a>

The send request.

For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.

---

##### `sendFile` <a name="sendFile" id="@wasend/core.WasendClient.sendFile"></a>

```typescript
public sendFile(request: MessageFileRequest): WAMessage
```

Send a file message.

*Example*

```typescript
curl -X POST 'http://localhost:3001/sendFile' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "session": "sessionId",
    "to": "+11111111111",
    "url": "https://example.com/file.pdf",
    "fileName": "document.pdf",
    "mimeType": "application/pdf"
  }'
```


###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.sendFile.parameter.request"></a>

- *Type:* <a href="#@wasend/core.MessageFileRequest">MessageFileRequest</a>

The file message request.

For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.

---

##### `sendImage` <a name="sendImage" id="@wasend/core.WasendClient.sendImage"></a>

```typescript
public sendImage(request: MessageImageRequest): WAMessage
```

Send an image message.

*Example*

```typescript
curl -X POST 'http://localhost:3001/sendImage' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "session": "sessionId",
    "to": "+11111111111",
    "url": "https://example.com/image.jpg",
    "caption": "Check out this image!"
  }'
```


###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.sendImage.parameter.request"></a>

- *Type:* <a href="#@wasend/core.MessageImageRequest">MessageImageRequest</a>

The image message request.

For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.

---

##### `sendLinkCustomPreview` <a name="sendLinkCustomPreview" id="@wasend/core.WasendClient.sendLinkCustomPreview"></a>

```typescript
public sendLinkCustomPreview(request: MessageLinkCustomPreviewRequest): WAMessage
```

Send a text message with custom link preview.

*Example*

```typescript
curl -X POST 'http://localhost:3001/send/link-custom-preview' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "session": "sessionId",
    "to": "+11111111111",
    "text": "Check out this link!",
    "preview": {
      "title": "Example Website",
      "description": "A great website",
      "thumbnailUrl": "https://example.com/thumbnail.jpg"
    }
  }'
```


###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.sendLinkCustomPreview.parameter.request"></a>

- *Type:* <a href="#@wasend/core.MessageLinkCustomPreviewRequest">MessageLinkCustomPreviewRequest</a>

The message with custom link preview request.

For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.

---

##### `sendMessage` <a name="sendMessage" id="@wasend/core.WasendClient.sendMessage"></a>

```typescript
public sendMessage(request: MessageRequest): ApiResponse
```

Send a message to a recipient.

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.sendMessage.parameter.request"></a>

- *Type:* <a href="#@wasend/core.MessageRequest">MessageRequest</a>

The message to send.

---

##### `sendSeen` <a name="sendSeen" id="@wasend/core.WasendClient.sendSeen"></a>

```typescript
public sendSeen(request: SendSeenRequest): void
```

Mark a message as seen.

*Example*

```typescript
curl -X POST 'http://localhost:3001/sendSeen' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "session": "sessionId",
    "to": "+11111111111",
    "messageId": "messageId"
  }'
```


###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.sendSeen.parameter.request"></a>

- *Type:* <a href="#@wasend/core.SendSeenRequest">SendSeenRequest</a>

The send seen request.

For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.

---

##### `sendText` <a name="sendText" id="@wasend/core.WasendClient.sendText"></a>

```typescript
public sendText(request: MessageTextRequest): WAMessage
```

Send a text message.

*Example*

```typescript
curl -X POST 'http://localhost:3001/sendText' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "session": "sessionId",
    "to": "+11111111111",
    "text": "Hello, World!"
  }'
```


###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.sendText.parameter.request"></a>

- *Type:* <a href="#@wasend/core.MessageTextRequest">MessageTextRequest</a>

The text message request.

For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.

---

##### `sendVideo` <a name="sendVideo" id="@wasend/core.WasendClient.sendVideo"></a>

```typescript
public sendVideo(request: MessageVideoRequest): WAMessage
```

Send a video message.

*Example*

```typescript
curl -X POST 'http://localhost:3001/sendVideo' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "session": "sessionId",
    "to": "+11111111111",
    "url": "https://example.com/video.mp4",
    "caption": "Check out this video!"
  }'
```


###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.sendVideo.parameter.request"></a>

- *Type:* <a href="#@wasend/core.MessageVideoRequest">MessageVideoRequest</a>

The video message request.

For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.

---

##### `sendVoice` <a name="sendVoice" id="@wasend/core.WasendClient.sendVoice"></a>

```typescript
public sendVoice(request: MessageVoiceRequest): WAMessage
```

Send a voice message.

*Example*

```typescript
curl -X POST 'http://localhost:3001/sendVoice' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "session": "sessionId",
    "to": "+11111111111",
    "url": "https://example.com/voice.mp3",
    "duration": 30
  }'
```


###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.sendVoice.parameter.request"></a>

- *Type:* <a href="#@wasend/core.MessageVoiceRequest">MessageVoiceRequest</a>

The voice message request.

For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.

---

##### `setGroupDescription` <a name="setGroupDescription" id="@wasend/core.WasendClient.setGroupDescription"></a>

```typescript
public setGroupDescription(sessionId: string, groupId: string, request: DescriptionRequest): void
```

Set group description.

*Example*

```typescript
curl -X PUT 'http://localhost:3001/{sessionId}/groups/{groupId}/description' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "description": "New group description"
  }'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.setGroupDescription.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.setGroupDescription.parameter.groupId"></a>

- *Type:* string

The group ID.

---

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.setGroupDescription.parameter.request"></a>

- *Type:* <a href="#@wasend/core.DescriptionRequest">DescriptionRequest</a>

The description request.

---

##### `setGroupInfoAdminOnly` <a name="setGroupInfoAdminOnly" id="@wasend/core.WasendClient.setGroupInfoAdminOnly"></a>

```typescript
public setGroupInfoAdminOnly(sessionId: string, groupId: string, request: SettingsSecurityChangeInfo): void
```

Set group info admin only setting.

*Example*

```typescript
curl -X PUT 'http://localhost:3001/{sessionId}/groups/{groupId}/settings/security/info-admin-only' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "enabled": true
  }'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.setGroupInfoAdminOnly.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.setGroupInfoAdminOnly.parameter.groupId"></a>

- *Type:* string

The group ID.

---

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.setGroupInfoAdminOnly.parameter.request"></a>

- *Type:* <a href="#@wasend/core.SettingsSecurityChangeInfo">SettingsSecurityChangeInfo</a>

The settings security change info.

---

##### `setGroupMessagesAdminOnly` <a name="setGroupMessagesAdminOnly" id="@wasend/core.WasendClient.setGroupMessagesAdminOnly"></a>

```typescript
public setGroupMessagesAdminOnly(sessionId: string, groupId: string, request: SettingsSecurityChangeInfo): void
```

Set group messages admin only setting.

*Example*

```typescript
curl -X PUT 'http://localhost:3001/{sessionId}/groups/{groupId}/settings/security/messages-admin-only' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "enabled": true
  }'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.setGroupMessagesAdminOnly.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.setGroupMessagesAdminOnly.parameter.groupId"></a>

- *Type:* string

The group ID.

---

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.setGroupMessagesAdminOnly.parameter.request"></a>

- *Type:* <a href="#@wasend/core.SettingsSecurityChangeInfo">SettingsSecurityChangeInfo</a>

The settings security change info.

---

##### `setGroupPicture` <a name="setGroupPicture" id="@wasend/core.WasendClient.setGroupPicture"></a>

```typescript
public setGroupPicture(sessionId: string, groupId: string, request: ProfilePictureRequest): void
```

Set group picture.

*Example*

```typescript
curl -X PUT 'http://localhost:3001/{sessionId}/groups/{groupId}/picture' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "url": "https://example.com/picture.jpg",
    "format": "jpeg",
    "cropToSquare": true
  }'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.setGroupPicture.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.setGroupPicture.parameter.groupId"></a>

- *Type:* string

The group ID.

---

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.setGroupPicture.parameter.request"></a>

- *Type:* <a href="#@wasend/core.ProfilePictureRequest">ProfilePictureRequest</a>

The profile picture request.

---

##### `setGroupSubject` <a name="setGroupSubject" id="@wasend/core.WasendClient.setGroupSubject"></a>

```typescript
public setGroupSubject(sessionId: string, groupId: string, request: SubjectRequest): void
```

Set group subject.

*Example*

```typescript
curl -X PUT 'http://localhost:3001/{sessionId}/groups/{groupId}/subject' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "subject": "New group name"
  }'
```


###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.setGroupSubject.parameter.sessionId"></a>

- *Type:* string

The session ID.

---

###### `groupId`<sup>Required</sup> <a name="groupId" id="@wasend/core.WasendClient.setGroupSubject.parameter.groupId"></a>

- *Type:* string

The group ID.

---

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.setGroupSubject.parameter.request"></a>

- *Type:* <a href="#@wasend/core.SubjectRequest">SubjectRequest</a>

The subject request.

---

##### `startSession` <a name="startSession" id="@wasend/core.WasendClient.startSession"></a>

```typescript
public startSession(sessionId: string): Session
```

###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.startSession.parameter.sessionId"></a>

- *Type:* string

---

##### `startTyping` <a name="startTyping" id="@wasend/core.WasendClient.startTyping"></a>

```typescript
public startTyping(request: ChatRequest): void
```

Start typing indicator.

*Example*

```typescript
curl -X POST 'http://localhost:3001/startTyping' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "session": "sessionId",
    "to": "+11111111111"
  }'
```


###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.startTyping.parameter.request"></a>

- *Type:* <a href="#@wasend/core.ChatRequest">ChatRequest</a>

The chat request.

For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.

---

##### `stopSession` <a name="stopSession" id="@wasend/core.WasendClient.stopSession"></a>

```typescript
public stopSession(sessionId: string): Session
```

###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.stopSession.parameter.sessionId"></a>

- *Type:* string

---

##### `stopTyping` <a name="stopTyping" id="@wasend/core.WasendClient.stopTyping"></a>

```typescript
public stopTyping(request: ChatRequest): void
```

Stop typing indicator.

*Example*

```typescript
curl -X POST 'http://localhost:3001/stopTyping' \
  -H 'Authorization: Bearer {apiKey}' \
  -H 'Content-Type: application/json' \
  -d '{
    "session": "sessionId",
    "to": "+11111111111"
  }'
```


###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.stopTyping.parameter.request"></a>

- *Type:* <a href="#@wasend/core.ChatRequest">ChatRequest</a>

The chat request.

For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.

---




### WasendUtils <a name="WasendUtils" id="@wasend/core.WasendUtils"></a>

Utility functions for the Wasend SDK.

#### Initializers <a name="Initializers" id="@wasend/core.WasendUtils.Initializer"></a>

```typescript
import { WasendUtils } from '@wasend/core'

new WasendUtils()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---


#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@wasend/core.WasendUtils.formatPhoneNumber">formatPhoneNumber</a></code> | Format a phone number to international format. |
| <code><a href="#@wasend/core.WasendUtils.isValidPhoneNumber">isValidPhoneNumber</a></code> | Check if a phone number is valid. |

---

##### `formatPhoneNumber` <a name="formatPhoneNumber" id="@wasend/core.WasendUtils.formatPhoneNumber"></a>

```typescript
import { WasendUtils } from '@wasend/core'

WasendUtils.formatPhoneNumber(phoneNumber: string, countryCode?: string)
```

Format a phone number to international format.

###### `phoneNumber`<sup>Required</sup> <a name="phoneNumber" id="@wasend/core.WasendUtils.formatPhoneNumber.parameter.phoneNumber"></a>

- *Type:* string

The phone number to format.

---

###### `countryCode`<sup>Optional</sup> <a name="countryCode" id="@wasend/core.WasendUtils.formatPhoneNumber.parameter.countryCode"></a>

- *Type:* string

Optional country code to use.

---

##### `isValidPhoneNumber` <a name="isValidPhoneNumber" id="@wasend/core.WasendUtils.isValidPhoneNumber"></a>

```typescript
import { WasendUtils } from '@wasend/core'

WasendUtils.isValidPhoneNumber(phoneNumber: string)
```

Check if a phone number is valid.

###### `phoneNumber`<sup>Required</sup> <a name="phoneNumber" id="@wasend/core.WasendUtils.isValidPhoneNumber.parameter.phoneNumber"></a>

- *Type:* string

The phone number to validate.

---




## Enums <a name="Enums" id="Enums"></a>

### GroupParticipantRole <a name="GroupParticipantRole" id="@wasend/core.GroupParticipantRole"></a>

Group participant role.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@wasend/core.GroupParticipantRole.PARTICIPANT">PARTICIPANT</a></code> | Regular participant. |
| <code><a href="#@wasend/core.GroupParticipantRole.ADMIN">ADMIN</a></code> | Group admin. |
| <code><a href="#@wasend/core.GroupParticipantRole.OWNER">OWNER</a></code> | Group owner. |

---

##### `PARTICIPANT` <a name="PARTICIPANT" id="@wasend/core.GroupParticipantRole.PARTICIPANT"></a>

Regular participant.

---


##### `ADMIN` <a name="ADMIN" id="@wasend/core.GroupParticipantRole.ADMIN"></a>

Group admin.

---


##### `OWNER` <a name="OWNER" id="@wasend/core.GroupParticipantRole.OWNER"></a>

Group owner.

---


### GroupStatus <a name="GroupStatus" id="@wasend/core.GroupStatus"></a>

Group status.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@wasend/core.GroupStatus.ACTIVE">ACTIVE</a></code> | Group is active. |
| <code><a href="#@wasend/core.GroupStatus.ARCHIVED">ARCHIVED</a></code> | Group is archived. |
| <code><a href="#@wasend/core.GroupStatus.DELETED">DELETED</a></code> | Group is deleted. |

---

##### `ACTIVE` <a name="ACTIVE" id="@wasend/core.GroupStatus.ACTIVE"></a>

Group is active.

---


##### `ARCHIVED` <a name="ARCHIVED" id="@wasend/core.GroupStatus.ARCHIVED"></a>

Group is archived.

---


##### `DELETED` <a name="DELETED" id="@wasend/core.GroupStatus.DELETED"></a>

Group is deleted.

---

