# Publishing Wasend SDK to PyPI

This guide provides detailed instructions for publishing the Wasend SDK to the Python Package Index (PyPI) using projen.

## Prerequisites

1. **PyPI Account**
   - Create an account at https://pypi.org/account/register/
   - Enable two-factor authentication (recommended)

2. **Required Tools**
   ```bash
   # Install projen globally
   npm install -g projen
   
   # Install Python build tools
   pip install --upgrade pip
   pip install build twine
   ```

## Step 1: Build the Package

1. **Clean and Build**
   ```bash
   # Clean any previous builds
   npm run clobber
   
   # Build the project
   npm run build
   
   # Package the Python version
   npm run package:python
   ```

2. **Verify Package Structure**
   ```bash
   cd dist/python
   ls -la
   ```
   You should see the generated Python package files.

## Step 2: Test Upload (Optional but Recommended)

1. **Upload to TestPyPI**
   ```bash
   # Create a TestPyPI account at https://test.pypi.org/
   twine upload --repository testpypi dist/*
   ```

2. **Test Installation**
   ```bash
   pip install --index-url https://test.pypi.org/simple/ wasend
   ```

## Step 3: Upload to PyPI

1. **Upload to PyPI**
   ```bash
   twine upload dist/*
   ```

2. **Verify Upload**
   - Visit https://pypi.org/project/wasend/
   - Check if your package is listed
   - Verify version and metadata

## Step 4: Test Installation

1. **Install from PyPI**
   ```bash
   pip install wasend
   ```

2. **Verify Installation**
   ```python
   python -c "import wasend; print(wasend.__version__)"
   ```

## Common Issues and Solutions

### 1. Authentication Errors
```bash
HTTPError: 403 Client Error: Invalid or non-existent authentication information
```
Solution:
- Ensure you're using the correct username/password
- Check if 2FA is enabled and use an API token instead

### 2. Package Already Exists
```bash
HTTPError: 400 Client Error: File already exists
```
Solution:
- Increment the version number in `package.json`
- Rebuild and repackage

### 3. Build Failures
```bash
Error: Failed to build Python package
```
Solution:
- Clean the project: `npm run clobber`
- Rebuild: `npm run build`
- Check for TypeScript compilation errors

## Best Practices

1. **Version Management**
   - Use semantic versioning (MAJOR.MINOR.PATCH)
   - Never re-upload the same version
   - Test each version before publishing

2. **Security**
   - Never commit PyPI credentials
   - Use environment variables for sensitive data
   - Enable 2FA on your PyPI account

## Support

For additional help:
- Email: admin@wasend.dev
- Documentation: https://docs.wasend.dev
- GitHub Issues: https://github.com/wasenddev/wasend-sdk/issues 