/**
 * Contact information
 */
export interface Contact {
    /**
     * Contact ID (phone number with @c.us suffix)
     * @example "11111111111@c.us"
     */
    readonly id: string;
    /**
     * Contact name
     */
    readonly name?: string;
    /**
     * Contact phone number
     */
    readonly phoneNumber: string;
    /**
     * Contact push name
     */
    readonly pushName?: string;
    /**
     * Contact profile picture URL
     */
    readonly profilePictureUrl?: string;
    /**
     * Contact status
     */
    readonly status?: string;
    /**
     * Contact business profile
     */
    readonly businessProfile?: Record<string, string>;
}
/**
 * WhatsApp number existence check result
 */
export interface WANumberExistResult {
    /**
     * Whether the number exists on WhatsApp
     */
    readonly exists: boolean;
    /**
     * The phone number that was checked
     */
    readonly phone: string;
    /**
     * The JID of the contact if it exists
     */
    readonly jid?: string;
}
/**
 * Profile picture response
 */
export interface ProfilePictureResponse {
    /**
     * The URL of the profile picture
     */
    readonly url: string;
    /**
     * The format of the picture (e.g., 'jpeg', 'png')
     */
    readonly format?: string;
    /**
     * The size of the picture in bytes
     */
    readonly size?: number;
    /**
     * The dimensions of the picture
     * @example
     * {
     *   "width": "800",
     *   "height": "600"
     * }
     */
    readonly dimensions?: {
        [key: string]: string;
    };
}
/**
 * Get contacts query parameters
 */
export interface GetContactsQueryParams {
    /**
     * Sort by field
     */
    readonly sortBy?: 'id' | 'name';
    /**
     * Sort order
     */
    readonly sortOrder?: 'desc' | 'asc';
    /**
     * Maximum number of results
     * @default 10
     */
    readonly limit?: number;
    /**
     * Number of results to skip
     * @default 0
     */
    readonly offset?: number;
}
/**
 * Get contact query parameters
 */
export interface GetContactQueryParams {
    /**
     * Contact ID (phone number with @c.us suffix)
     * @example "11111111111@c.us"
     */
    readonly contactId: string;
}
/**
 * Check contact exists query parameters
 */
export interface CheckContactExistsQueryParams {
    /**
     * The phone number to check
     * @example "1213213213"
     */
    readonly phone: string;
}
/**
 * Get profile picture query parameters
 */
export interface GetProfilePictureQueryParams {
    /**
     * Contact ID (phone number with @c.us suffix)
     * @example "11111111111@c.us"
     */
    readonly contactId: string;
    /**
     * Refresh the picture from the server (24h cache by default)
     * @default false
     */
    readonly refresh?: boolean;
}
